@@ -1,20 +1,11 @@
 // Copyright (c) 2006-2009 Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Algebraic_curve_kernel_2.h $
-// $Id: Algebraic_curve_kernel_2.h 26c857a %aI Mael Rouxel-Labbé
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Algebraic_curve_kernel_2.h $
+// $Id: Algebraic_curve_kernel_2.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Eric Berberich <eric@mpi-inf.mpg.de>
@@ -408,7 +399,19 @@ public:
     }
     
 public: 
+    static auto initialize_poly_0() {
+      Polynomial_2 poly_0;
+      return poly_0;
+    }
     static Algebraic_curve_kernel_2& get_static_instance(){
+      // Useless reference to a `Polynomial_2` to force the creation
+      // of `CORE::MemoryPool<CORE::Bigfloat>` (and related type)
+      // before the static thread-local instance `ack_2_instance`.
+      // The issue is otherwise that the memory pool is created during
+      // the filling of the curves cache, and then destroyed too soon,
+      // before the destruction of `ack_2_instance`.
+      CGAL_STATIC_THREAD_LOCAL_VARIABLE(Polynomial_2, poly_0, initialize_poly_0());
+      CGAL_USE(poly_0);
       // a default constructed ack_2 instance
       CGAL_STATIC_THREAD_LOCAL_VARIABLE_0(Algebraic_curve_kernel_2, ack_2_instance);
       return ack_2_instance;
@@ -736,7 +739,7 @@ public:
       
     public:
 
-      typedef CGAL::cpp11::array<Bound,4> result_type;
+      typedef std::array<Bound,4> result_type;
 
       Isolate_2(const Algebraic_kernel_d_2* kernel) 
 	: _m_kernel(kernel) {}
