@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Arrangement_on_surface_2/include/CGAL/Arr_dcel_base.h $
-// $Id: Arr_dcel_base.h f0c1d3a %aI Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Arrangement_on_surface_2/include/CGAL/Arr_dcel_base.h $
+// $Id: Arr_dcel_base.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Ron Wein <wein@post.tau.ac.il>
@@ -92,31 +83,31 @@ protected:
 public:
   /*! Default constructor. */
   Arr_vertex_base() :
-    p_inc(NULL),
-    p_pt(NULL)
+    p_inc(nullptr),
+    p_pt(nullptr)
   { pss[0] = pss[1] = static_cast<char>(CGAL::ARR_INTERIOR); }
 
   /*! Destructor. */
   virtual ~Arr_vertex_base() {}
 
-  /*! Check if the point pointer is NULL. */
-  bool has_null_point() const { return (p_pt == NULL); }
+  /*! Check if the point pointer is nullptr. */
+  bool has_null_point() const { return (p_pt == nullptr); }
 
   /*! Get the point (const version). */
   const Point& point() const
   {
-    CGAL_assertion(p_pt != NULL);
+    CGAL_assertion(p_pt != nullptr);
     return (*p_pt);
   }
 
   /*! Get the point (non-const version). */
   Point& point()
   {
-    CGAL_assertion(p_pt != NULL);
+    CGAL_assertion(p_pt != nullptr);
     return (*p_pt);
   }
 
-  /*! Set the point (may be a NULL point). */
+  /*! Set the point (may be a nullptr point). */
   void set_point(Point* p) { p_pt = p; }
 
   /*! Get the boundary type in x. */
@@ -175,31 +166,31 @@ protected:
 public:
   /*! Default constructor */
   Arr_halfedge_base() :
-    p_opp(NULL),
-    p_prev(NULL),
-    p_next(NULL),
-    p_v(NULL),
-    p_comp(NULL),
-    p_cv(NULL)
+    p_opp(nullptr),
+    p_prev(nullptr),
+    p_next(nullptr),
+    p_v(nullptr),
+    p_comp(nullptr),
+    p_cv(nullptr)
   {}
 
   /*! Destructor. */
   virtual ~Arr_halfedge_base() {}
 
-  /*! Check if the curve pointer is NULL. */
-  bool has_null_curve() const { return (p_cv == NULL); }
+  /*! Check if the curve pointer is nullptr. */
+  bool has_null_curve() const { return (p_cv == nullptr); }
 
   /*! Get the x-monotone curve (const version). */
   const X_monotone_curve& curve() const
   {
-    CGAL_precondition(p_cv != NULL);
+    CGAL_precondition(p_cv != nullptr);
     return (*p_cv);
   }
 
   /*! Get the x-monotone curve (non-const version). */
   X_monotone_curve& curve()
   {
-    CGAL_precondition(p_cv != NULL);
+    CGAL_precondition(p_cv != nullptr);
     return (*p_cv);
   }
 
@@ -712,7 +703,7 @@ private:
 
 public:
   /*! Default constructor. */
-  Arr_outer_ccb() : p_f(NULL), iter_is_not_singular(false) {}
+  Arr_outer_ccb() : p_f(nullptr), iter_is_not_singular(false) {}
 
   /*! Copy constructor. */
   Arr_outer_ccb(const Arr_outer_ccb& other) :
@@ -778,7 +769,7 @@ private:
 
 public:
   /*! Default constructor. */
-  Arr_inner_ccb() : p_f(NULL), iter_is_not_singular(false) {}
+  Arr_inner_ccb() : p_f(nullptr), iter_is_not_singular(false) {}
 
   /*! Copy constructor. */
   Arr_inner_ccb(const Arr_inner_ccb& other) :
@@ -843,7 +834,7 @@ private:
 
 public:
   /*! Default constructor. */
-  Arr_isolated_vertex() : p_f(NULL), iter_is_not_singular(false) {}
+  Arr_isolated_vertex() : p_f(nullptr), iter_is_not_singular(false) {}
 
   /*! Copy constructor. */
   Arr_isolated_vertex(const Arr_isolated_vertex& other) :
@@ -908,7 +899,6 @@ protected:
   typedef In_place_list<Inner_ccb, false>        Inner_ccb_list;
   typedef In_place_list<Isolated_vertex, false>  Iso_vert_list;
 
-#ifdef CGAL_CXX11
     typedef std::allocator_traits<Allocator> Allocator_traits;
     typedef typename Allocator_traits::template rebind_alloc<Vertex>          Vertex_allocator;
     typedef typename Allocator_traits::template rebind_alloc<Halfedge>        Halfedge_allocator;
@@ -916,32 +906,6 @@ protected:
     typedef typename Allocator_traits::template rebind_alloc<Outer_ccb>       Outer_ccb_allocator;
     typedef typename Allocator_traits::template rebind_alloc<Inner_ccb>       Inner_ccb_allocator;
     typedef typename Allocator_traits::template rebind_alloc<Isolated_vertex> Iso_vert_allocator;
-#else // not CGAL_CXX11
-  // Vertex allocator.
-  typedef typename Allocator::template rebind<Vertex>    Vertex_alloc_rebind;
-  typedef typename Vertex_alloc_rebind::other            Vertex_allocator;
-
-  // Halfedge allocator.
-  typedef typename Allocator::template rebind<Halfedge>  Halfedge_alloc_rebind;
-  typedef typename Halfedge_alloc_rebind::other          Halfedge_allocator;
-
-  // Face allocator.
-  typedef typename Allocator::template rebind<Face>      Face_alloc_rebind;
-  typedef typename Face_alloc_rebind::other              Face_allocator;
-
-  // Outer CCB allocator.
-  typedef typename Allocator::template rebind<Outer_ccb> Out_ccb_alloc_rebind;
-  typedef typename Out_ccb_alloc_rebind::other           Outer_ccb_allocator;
-
-  // Inner CCB allocator.
-  typedef typename Allocator::template rebind<Inner_ccb> In_ccb_alloc_rebind;
-  typedef typename In_ccb_alloc_rebind::other            Inner_ccb_allocator;
-
-  // Isolated vertex allocator.
-  typedef typename Allocator::template rebind<Isolated_vertex>
-                                                         Iso_vert_alloc_rebind;
-  typedef typename Iso_vert_alloc_rebind::other          Iso_vert_allocator;
-#endif // not CGAL_CXX11
 
 public:
   typedef typename Halfedge_list::size_type              Size;
@@ -1089,11 +1053,7 @@ public:
   Vertex* new_vertex()
   {
     Vertex* v = vertex_alloc.allocate(1);
-#ifdef CGAL_CXX11
     std::allocator_traits<Vertex_allocator>::construct(vertex_alloc,v);
-#else
-    vertex_alloc.construct(v, Vertex());
-#endif
     vertices.push_back(*v);
     return v;
   }
@@ -1116,11 +1076,7 @@ public:
   Face* new_face()
   {
     Face* f = face_alloc.allocate(1);
-#ifdef CGAL_CXX11
     std::allocator_traits<Face_allocator>::construct(face_alloc, f);
-#else
-    face_alloc.construct(f, Face());
-#endif
     faces.push_back (*f);
     return(f);
   }
@@ -1129,11 +1085,7 @@ public:
   Outer_ccb* new_outer_ccb()
   {
     Outer_ccb* oc = out_ccb_alloc.allocate(1);
-#ifdef CGAL_CXX11
     std::allocator_traits<Outer_ccb_allocator>::construct(out_ccb_alloc, oc);
-#else
-    out_ccb_alloc.construct(oc, Outer_ccb());
-#endif
     out_ccbs.push_back(*oc);
     return (oc);
   }
@@ -1142,11 +1094,7 @@ public:
   Inner_ccb* new_inner_ccb()
   {
     Inner_ccb* ic = in_ccb_alloc.allocate(1);
-#ifdef CGAL_CXX11
     std::allocator_traits<Inner_ccb_allocator>::construct(in_ccb_alloc, ic);
-#else
-    in_ccb_alloc.construct(ic, Inner_ccb());
-#endif
     in_ccbs.push_back(*ic);
     return (ic);
   }
@@ -1155,11 +1103,7 @@ public:
   Isolated_vertex* new_isolated_vertex()
   {
     Isolated_vertex* iv = iso_vert_alloc.allocate(1);
-#ifdef CGAL_CXX11
     std::allocator_traits<Iso_vert_allocator>::construct(iso_vert_alloc, iv);
-#else
-    iso_vert_alloc.construct(iv, Isolated_vertex());
-#endif
     iso_verts.push_back(*iv);
     return (iv);
   }
@@ -1171,11 +1115,7 @@ public:
   void delete_vertex(Vertex* v)
   {
     vertices.erase(v);
-#ifdef CGAL_CXX11
     std::allocator_traits<Vertex_allocator>::destroy(vertex_alloc, v);
-#else
-    vertex_alloc.destroy(v);
-#endif
     vertex_alloc.deallocate(v,1);
   }
 
@@ -1191,11 +1131,7 @@ public:
   void delete_face(Face* f)
   {
     faces.erase(f);
-#ifdef CGAL_CXX11
     std::allocator_traits<Face_allocator>::destroy(face_alloc, f);
-#else
-    face_alloc.destroy(f);
-#endif
     face_alloc.deallocate(f, 1);
   }
 
@@ -1203,11 +1139,7 @@ public:
   void delete_outer_ccb(Outer_ccb* oc)
   {
     out_ccbs.erase(oc);
-#ifdef CGAL_CXX11
     std::allocator_traits<Outer_ccb_allocator>::destroy(out_ccb_alloc, oc);
-#else
-    out_ccb_alloc.destroy(oc);
-#endif
     out_ccb_alloc.deallocate(oc, 1);
   }
 
@@ -1215,11 +1147,7 @@ public:
   void delete_inner_ccb(Inner_ccb* ic)
   {
     in_ccbs.erase(ic);
-#ifdef CGAL_CXX11
     std::allocator_traits<Inner_ccb_allocator>::destroy(in_ccb_alloc, ic);
-#else
-    in_ccb_alloc.destroy(ic);
-#endif
     in_ccb_alloc.deallocate(ic, 1);
   }
 
@@ -1227,11 +1155,7 @@ public:
   void delete_isolated_vertex(Isolated_vertex* iv)
   {
     iso_verts.erase(iv);
-#ifdef CGAL_CXX11
     std::allocator_traits<Iso_vert_allocator>::destroy(iso_vert_alloc, iv);
-#else
-    iso_vert_alloc.destroy(iv);
-#endif
     iso_vert_alloc.deallocate(iv, 1);
   }
 
@@ -1492,11 +1416,7 @@ protected:
   Halfedge* _new_halfedge()
   {
     Halfedge* h = halfedge_alloc.allocate(1);
-#ifdef CGAL_CXX11
     std::allocator_traits<Halfedge_allocator>::construct(halfedge_alloc, h);
-#else
-    halfedge_alloc.construct(h, Halfedge());
-#endif
     halfedges.push_back(*h);
     return (h);
   }
@@ -1505,11 +1425,7 @@ protected:
   void _delete_halfedge(Halfedge* h)
   {
     halfedges.erase(h);
-#ifdef CGAL_CXX11
     std::allocator_traits<Halfedge_allocator>::destroy(halfedge_alloc,h);
-#else
-    halfedge_alloc.destroy(h);
-#endif
     halfedge_alloc.deallocate(h, 1);
   }
 };
