@@ -1,20 +1,11 @@
 // Copyright (c) 2005-2009  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/CGAL_ipelets/include/CGAL/CGAL_Ipelet_base_v7.h $
-// $Id: CGAL_Ipelet_base_v7.h da2726e %aI Laurent Rineau
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/CGAL_ipelets/include/CGAL/CGAL_Ipelet_base_v7.h $
+// $Id: CGAL_Ipelet_base_v7.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Sebastien Loriot, Sylvain Pion
@@ -103,11 +94,11 @@ namespace CGAL{
     typedef CGAL::Polygon_2<Kernel>                                           Polygon_2;
   
     typedef typename Kernel::Circle_2                                         Circle_2;
-    typedef CGAL::cpp11::tuple<Circle_2,Point_2,Point_2,CGAL::Sign>           Circular_arc_2;
+    typedef std::tuple<Circle_2,Point_2,Point_2,CGAL::Sign>           Circular_arc_2;
   
   
     Ipelet_base(const std::string NameS,const std::string SubLabS[],const std::string HMsgS[])
-      :SubLab(&SubLabS[0]),HMsg(&HMsgS[0]),Name(NameS),data_(NULL),helper_(NULL){};
+      :SubLab(&SubLabS[0]),HMsg(&HMsgS[0]),Name(NameS),data_(nullptr),helper_(nullptr){};
     
     
     ipe::Page* get_IpePage() const {return data_->iPage;}
@@ -127,7 +118,7 @@ namespace CGAL{
         return true;
       }
       catch(...){
-        helper->messageBox("Error : Save your page in a file and submit it to \n https://www.cgal.org/bug_report.html",NULL,ipe::IpeletHelper::EOkCancelButtons);
+        helper->messageBox("Error : Save your page in a file and submit it to \n https://www.cgal.org/bug_report.html",nullptr,ipe::IpeletHelper::EOkCancelButtons);
         return false;
       }
     };
@@ -142,7 +133,7 @@ namespace CGAL{
           hmsg=hmsg+"<li><i>"+SubLab[i]+"</i>: "+HMsg[i]+"</li>";
       else
         hmsg=hmsg+"<li>"+HMsg[0]+"</li>";
-      get_IpeletHelper()->messageBox(&hmsg[0],NULL,ipe::IpeletHelper::EOkCancelButtons);
+      get_IpeletHelper()->messageBox(&hmsg[0],nullptr,ipe::IpeletHelper::EOkCancelButtons);
       return;
     }
 
@@ -350,7 +341,7 @@ public:
           SSP_ipe->setClosed(true);
         return SSP_ipe;
       }
-      return NULL;
+      return nullptr;
     }
     
     
@@ -364,10 +355,10 @@ public:
                                       typename std::iterator_traits<iterator>::value_type,
                                       Point_2
                                     > 
-                                  >::type* =NULL) const 
+                                  >::type* =nullptr) const 
     {
       ipe::Curve* SSP_ipe=create_polyline(first,last,setclose);
-      if (SSP_ipe!=NULL){
+      if (SSP_ipe!=nullptr){
         ipe::Shape shape;
         shape.appendSubPath(SSP_ipe);
         ipe::Path* obj_ipe=new ipe::Path(CURRENTATTRIBUTES,shape);
@@ -378,7 +369,7 @@ public:
         get_IpePage()->append( (deselect_all?ipe::ENotSelected:get_selection_type()),CURRENTLAYER,obj_ipe);
         return obj_ipe;
       }
-      return NULL;  
+      return nullptr;  
     }
     
     void draw_in_ipe(const Circle_2& C,bool deselect_all=false) const {
@@ -422,15 +413,15 @@ public:
     draw_in_ipe(const Circular_arc_2& arc,bool deselect_all=false) const 
     {
       ipe::Curve* SSP_ipe = new ipe::Curve;
-      ipe::Vector ipeS=ipe::Vector( CGAL::to_double(CGAL::cpp11::get<1>(arc).x()),
-                                CGAL::to_double(CGAL::cpp11::get<1>(arc).y()));//convert ot ipe format
-      ipe::Vector ipeT=ipe::Vector( CGAL::to_double(CGAL::cpp11::get<2>(arc).x()),
-                                CGAL::to_double(CGAL::cpp11::get<2>(arc).y()));//convert ot ipe format
-      SSP_ipe->appendArc(ipe::Matrix(sqrt(CGAL::to_double(CGAL::cpp11::get<0>(arc).squared_radius())),0,
-                                   0,(CGAL::cpp11::get<3>(arc)==CGAL::COUNTERCLOCKWISE?1:-1)*
-                                     sqrt(CGAL::to_double(CGAL::cpp11::get<0>(arc).squared_radius())),
-                                   CGAL::to_double(CGAL::cpp11::get<0>(arc).center().x()),
-                                   CGAL::to_double(CGAL::cpp11::get<0>(arc).center().y())),
+      ipe::Vector ipeS=ipe::Vector( CGAL::to_double(std::get<1>(arc).x()),
+                                CGAL::to_double(std::get<1>(arc).y()));//convert ot ipe format
+      ipe::Vector ipeT=ipe::Vector( CGAL::to_double(std::get<2>(arc).x()),
+                                CGAL::to_double(std::get<2>(arc).y()));//convert ot ipe format
+      SSP_ipe->appendArc(ipe::Matrix(sqrt(CGAL::to_double(std::get<0>(arc).squared_radius())),0,
+                                   0,(std::get<3>(arc)==CGAL::COUNTERCLOCKWISE?1:-1)*
+                                     sqrt(CGAL::to_double(std::get<0>(arc).squared_radius())),
+                                   CGAL::to_double(std::get<0>(arc).center().x()),
+                                   CGAL::to_double(std::get<0>(arc).center().y())),
                                    ipeS,ipeT);
       ipe::Shape shape;
       shape.appendSubPath(SSP_ipe);
@@ -490,17 +481,17 @@ public:
     draw_in_ipe(const Circular_arc_2& object,const Iso_rectangle_2& bbox,bool deselect_all=false) const 
     {
       std::vector<Circular_arc_2> arc_list;
-      const Circle_2& circle=CGAL::cpp11::get<0>(object);
+      const Circle_2& circle=std::get<0>(object);
       restrict_circle_to_bbox(circle,bbox,std::back_inserter(arc_list));
       if (arc_list.empty() && bbox.has_on_bounded_side(circle.center()) ){
         draw_in_ipe(object,deselect_all);
         return;
       }
       
-      const Point_2* source=(CGAL::cpp11::get<3>(object)==CGAL::COUNTERCLOCKWISE)?
-                            &CGAL::cpp11::get<1>(object):&CGAL::cpp11::get<2>(object);
-      const Point_2* target=(CGAL::cpp11::get<3>(object)==CGAL::COUNTERCLOCKWISE)?
-                            &CGAL::cpp11::get<2>(object):&CGAL::cpp11::get<1>(object);
+      const Point_2* source=(std::get<3>(object)==CGAL::COUNTERCLOCKWISE)?
+                            &std::get<1>(object):&std::get<2>(object);
+      const Point_2* target=(std::get<3>(object)==CGAL::COUNTERCLOCKWISE)?
+                            &std::get<2>(object):&std::get<1>(object);
       std::multimap<double,std::pair<Type_circ_arc,const Point_2*> > map_theta;
       typedef  typename std::multimap<double,std::pair<Type_circ_arc,const Point_2*> >::iterator Map_theta_iterator;
       Map_theta_iterator s_it=map_theta.insert(
@@ -510,10 +501,10 @@ public:
                                 std::make_pair(get_theta(*target,circle),std::make_pair(OTRG,target)));
       
       for (typename std::vector<Circular_arc_2>::iterator it_arc=arc_list.begin();it_arc!=arc_list.end();++it_arc){
-        const Point_2* arc_s=(CGAL::cpp11::get<3>(*it_arc)==CGAL::COUNTERCLOCKWISE)?
-                             &CGAL::cpp11::get<1>(*it_arc):&CGAL::cpp11::get<2>(*it_arc);
-        const Point_2* arc_t=(CGAL::cpp11::get<3>(*it_arc)==CGAL::COUNTERCLOCKWISE)?
-                             &CGAL::cpp11::get<2>(*it_arc):&CGAL::cpp11::get<1>(*it_arc);        
+        const Point_2* arc_s=(std::get<3>(*it_arc)==CGAL::COUNTERCLOCKWISE)?
+                             &std::get<1>(*it_arc):&std::get<2>(*it_arc);
+        const Point_2* arc_t=(std::get<3>(*it_arc)==CGAL::COUNTERCLOCKWISE)?
+                             &std::get<2>(*it_arc):&std::get<1>(*it_arc);        
         map_theta.insert( std::make_pair(get_theta(*arc_s,circle),std::make_pair(SRC,arc_s) ) );
         map_theta.insert( std::make_pair(get_theta(*arc_t,circle),std::make_pair(TRG,arc_t) ) );
       }
@@ -660,7 +651,7 @@ public:
                                  boost::mpl::or_< boost::is_same<typename std::iterator_traits<iterator>::value_type,Circular_arc_2> ,
                                                   boost::is_same<typename std::iterator_traits<iterator>::value_type,Polygon_2>
                                                 > > > >
-                    >::type* = NULL) const
+                    >::type* = nullptr) const
     {
       for (iterator it=begin;it!=end;++it)
         draw_in_ipe(*it,bbox);
@@ -779,9 +770,9 @@ public:
       Circle_2 approx_circle=conv(exact_circle);  
       if (!sign_known){
         CGAL::Sign sign = (CGAL::orientation(sd,td,center)==CGAL::LEFT_TURN)?CGAL::POSITIVE:CGAL::NEGATIVE;
-        return CGAL::cpp11::make_tuple(approx_circle,sd,td,sign);
+        return std::make_tuple(approx_circle,sd,td,sign);
       }
-      return CGAL::cpp11::make_tuple(approx_circle,sd,td,CGAL::POSITIVE);
+      return std::make_tuple(approx_circle,sd,td,CGAL::POSITIVE);
     }
 
     void 
