@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Circular_kernel_3/include/CGAL/Circular_kernel_3/internal_functions_on_sphere_3.h $
-// $Id: internal_functions_on_sphere_3.h 0d3ac75 %aI Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Circular_kernel_3/include/CGAL/Circular_kernel_3/internal_functions_on_sphere_3.h $
+// $Id: internal_functions_on_sphere_3.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Monique Teillaud, Sylvain Pion, Pedro Machado
 
@@ -29,6 +20,7 @@
 
 
 #include <CGAL/Circular_kernel_3/Intersection_traits.h>
+#include <CGAL/number_utils.h>
 #include <utility>
 #include <vector>
 
@@ -140,10 +132,10 @@ namespace CGAL {
     {
       // Should we compare anyway even if they are degenerated?
       CGAL_kernel_assertion(!(p1.is_degenerate() || p2.is_degenerate()));
-      if(is_zero(p1.a())) {
-        if(!is_zero(p2.a())) return false;
-        if(is_zero(p1.b())) {
-          if(!is_zero(p2.b())) return false;
+      if(CGAL::is_zero(p1.a())) {
+        if(!CGAL::is_zero(p2.a())) return false;
+        if(CGAL::is_zero(p1.b())) {
+          if(!CGAL::is_zero(p2.b())) return false;
           return p1.c() * p2.d() == p1.d() * p2.c();
         }
         return (p2.c() * p1.b() == p1.c() * p2.b()) &&
@@ -292,43 +284,25 @@ namespace CGAL {
        CGAL_kernel_precondition(!s2.is_degenerate());
        CGAL_kernel_precondition(!s3.is_degenerate());
        if(non_oriented_equal<SK>(s1,s2) && non_oriented_equal<SK>(s2,s3)) {
-         #if CGAL_INTERSECTION_VERSION < 2
-         *res++ = make_object(s1);
-         #else
          *res++ = result_type(s1);
-         #endif
          return res;
        }
        if(non_oriented_equal<SK>(s1,s2)) {
          if(typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v = 
             SK().intersect_3_object()(s1, s3)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           if( const Point_3* p = object_cast<Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(visitor,
              *v);
-           #endif
          }
          return res;
        }
        if(non_oriented_equal<SK>(s1,s3) || non_oriented_equal<SK>(s2,s3)) {
          if(typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v = 
             SK().intersect_3_object()(s1, s2)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           if( const Point_3* p = object_cast<Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(
              visitor,
              *v);
-           #endif
          }
          return res;
        }
@@ -338,21 +312,13 @@ namespace CGAL {
          if(!v) return res;
          if(const Point_3* p = CGAL::Intersections::internal::intersect_get<Point_3>(v)) {
             if(SK().has_on_3_object()(s3, *p)) {
-              #if CGAL_INTERSECTION_VERSION < 2
-              *res++ = make_object(std::make_pair(Circular_arc_point_3(*p),2u));
-              #else
               *res++ = result_type(std::make_pair(Circular_arc_point_3(*p),2u));
-              #endif
             }
              return res;
          }
          if(const Circle_3* c = CGAL::Intersections::internal::intersect_get<Circle_3>(v)) {
             if(SK().has_on_3_object()(s3, *c)) {
-              #if CGAL_INTERSECTION_VERSION < 2
-              *res++ = make_object(*c);
-              #else
               *res++ = result_type(*c);
-              #endif
             }
            return res;
          }
@@ -384,26 +350,16 @@ namespace CGAL {
       typedef typename SK::Plane_3  Plane_3;
       typedef typename SK::Sphere_3 Sphere_3;
       typedef typename SK::Algebraic_kernel  Algebraic_kernel;
-      #if CGAL_INTERSECTION_VERSION < 2
-      typedef typename SK::Circular_arc_point_3  Circular_arc_point_3;
-      #endif
       CGAL_kernel_precondition(!p.is_degenerate());
       CGAL_kernel_precondition(!s1.is_degenerate());
       CGAL_kernel_precondition(!s2.is_degenerate());
       if(non_oriented_equal<SK>(s1,s2)) {
         if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v = 
             SK().intersect_3_object()(p, s1)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           if( const typename SK::Point_3* p = CGAL::object_cast<typename SK::Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(
              visitor,
              *v);
-           #endif
          }
          return res;
       }
@@ -411,17 +367,10 @@ namespace CGAL {
       if(non_oriented_equal<SK>(p,radical_p)) {
         if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v = 
             SK().intersect_3_object()(p, s1)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           if( const typename SK::Point_3* p = CGAL::object_cast<typename SK::Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(
              visitor,
              *v);
-           #endif
          }
          return res;
       }
@@ -456,18 +405,10 @@ namespace CGAL {
       if(non_oriented_equal<SK>(p1,p2)) {
         if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v = 
             SK().intersect_3_object()(p1, s)) {
-           #if CGAL_INTERSECTION_VERSION < 2
-           typedef typename SK::Circular_arc_point_3  Circular_arc_point_3;
-           if( const typename SK::Point_3* p = CGAL::object_cast<typename SK::Point_3>(&v) )
-             *res++ = make_object(std::make_pair(Circular_arc_point_3(*p), 2u));
-           else
-             *res++ = v;
-           #else
            internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
            return boost::apply_visitor(
              visitor,
              *v);
-           #endif
          }
          return res;
       }
