@@ -1,20 +1,11 @@
 // Copyright (c) 2010-2011 CNRS and LIRIS' Establishments (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Combinatorial_map/include/CGAL/Combinatorial_map_basic_operations.h $
-// $Id: Combinatorial_map_basic_operations.h 241a9f3 %aI Guillaume Damiand
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Combinatorial_map/include/CGAL/Combinatorial_map_basic_operations.h $
+// $Id: Combinatorial_map_basic_operations.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
 //
@@ -268,7 +259,7 @@ namespace CGAL
   typename Map::size_type degree(const Map & amap, 
                                  typename Map::Dart_const_handle adart)
   {
-    CGAL_assertion(adart != NULL);
+    CGAL_assertion(adart != nullptr);
   
     typename Map::size_type nbIncident = 0;
     typename Map::size_type mark;
@@ -317,7 +308,7 @@ namespace CGAL
   typename Map::size_type codegree(const Map & amap, 
                                    typename Map::Dart_const_handle adart)
   {
-    CGAL_assertion(adart != NULL);
+    CGAL_assertion(adart != nullptr);
   
     typename Map::size_type nbIncident = 0;
     typename Map::size_type mark;
