@@ -1,20 +1,11 @@
 // Copyright (c) 2010-2011 CNRS and LIRIS' Establishments (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Combinatorial_map/include/CGAL/Combinatorial_map_save_load.h $
-// $Id: Combinatorial_map_save_load.h 0b0b150 %aI Laurent Rineau
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Combinatorial_map/include/CGAL/Combinatorial_map_save_load.h $
+// $Id: Combinatorial_map_save_load.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
 //                 Guillaume Castano <guillaume.castano@gmail.com>
@@ -23,7 +14,6 @@
 #ifndef CGAL_COMBINATORIAL_MAP_SAVE_LOAD_H
 #define CGAL_COMBINATORIAL_MAP_SAVE_LOAD_H
 
-#include <boost/foreach.hpp>
 #include <boost/property_tree/xml_parser.hpp>
 #include <boost/property_tree/ptree.hpp>
 #include <boost/lexical_cast.hpp>
@@ -525,8 +515,8 @@ namespace CGAL {
     static void run(const boost::property_tree::ptree& pt, CMap& amap,
                     const std::vector<typename CMap::Dart_handle>& myDarts)
     {
-      BOOST_FOREACH( const boost::property_tree::ptree::value_type &v0,
-                     pt.get_child("data.attributes") )
+      for(const boost::property_tree::ptree::value_type& v0 :
+          pt.get_child("data.attributes") )
       {
         // <dimension>
         if (v0.first == "dimension")
@@ -552,20 +542,20 @@ namespace CGAL {
                   return;
                   }*/
 
-            BOOST_FOREACH(const boost::property_tree::ptree::value_type &v1,
+            for(const boost::property_tree::ptree::value_type &v1 :
                           v0.second )
             {
               if( v1.first == "a" )
               {
                 id_dart_cellule=v1.second.get<unsigned int>("d")-1;
                 
-                BOOST_FOREACH(const boost::property_tree::ptree::value_type &v2,
+                for(const boost::property_tree::ptree::value_type &v2 :
                               v1.second )
                 {
                   if( type==type_map && v2.first == "v" )
                   {
                     if (amap.template attribute<i>(myDarts[id_dart_cellule])
-                        ==NULL )
+                        ==nullptr )
                       amap.template set_attribute<i>
                         (myDarts[id_dart_cellule],
                          amap.template create_attribute<i>());
@@ -576,7 +566,7 @@ namespace CGAL {
                   if( ptype==ptype_map && v2.first == "p" )
                   {
                     if (amap.template attribute<i>(myDarts[id_dart_cellule])
-                        ==NULL )
+                        ==nullptr )
                       amap.template set_attribute<i>
                         (myDarts[id_dart_cellule],
                          amap.template create_attribute<i>());
@@ -601,7 +591,7 @@ namespace CGAL {
     static void run(const boost::property_tree::ptree& pt, CMap& amap,
                     const std::vector<typename CMap::Dart_handle>& myDarts)
     {
-      BOOST_FOREACH( const boost::property_tree::ptree::value_type &v0,
+      for( const boost::property_tree::ptree::value_type &v0 :
                      pt.get_child("data.attributes") )
       {
         // <dimension>
@@ -623,20 +613,20 @@ namespace CGAL {
                   return;
                   }*/
 
-            BOOST_FOREACH(const boost::property_tree::ptree::value_type &v1,
+            for(const boost::property_tree::ptree::value_type &v1 :
                           v0.second )
             {
               if( v1.first == "a" )
               {
                 id_dart_cellule=v1.second.get<unsigned int>("d")-1;
                 
-                BOOST_FOREACH(const boost::property_tree::ptree::value_type &v2,
+                for(const boost::property_tree::ptree::value_type &v2 :
                               v1.second )
                 {
                   if( v2.first == "p" )
                   {
                     if (amap.template attribute<i>
-                        (myDarts[id_dart_cellule])==NULL )
+                        (myDarts[id_dart_cellule])==nullptr )
                       amap.template set_attribute<i>
                         (myDarts[id_dart_cellule],
                          amap.template create_attribute<i>());
@@ -662,7 +652,7 @@ namespace CGAL {
     static void run(const boost::property_tree::ptree& pt, CMap& amap,
                     const std::vector<typename CMap::Dart_handle>& myDarts)
     {
-      BOOST_FOREACH( const boost::property_tree::ptree::value_type &v0,
+      for( const boost::property_tree::ptree::value_type &v0 :
                      pt.get_child("data.attributes") )
       {
         // <dimension>
@@ -684,20 +674,20 @@ namespace CGAL {
                   return;
                   } */
 
-            BOOST_FOREACH(const boost::property_tree::ptree::value_type &v1,
+            for(const boost::property_tree::ptree::value_type &v1 :
                           v0.second )
             {
               if( v1.first == "a" )
               {
                 id_dart_cellule=v1.second.get<unsigned int>("d")-1;
                 
-                BOOST_FOREACH(const boost::property_tree::ptree::value_type &v2,
+                for(const boost::property_tree::ptree::value_type &v2 :
                               v1.second )
                 {
                   if( v2.first == "v" )
                   {
                     if (amap.template attribute<i>
-                        (myDarts[id_dart_cellule])==NULL)
+                        (myDarts[id_dart_cellule])==nullptr)
                       amap.template set_attribute<i>
                         (myDarts[id_dart_cellule],
                          amap.template create_attribute<i>());
@@ -721,7 +711,7 @@ namespace CGAL {
     static void run(const boost::property_tree::ptree& pt, CMap& amap,
                     const std::vector<typename CMap::Dart_handle>& myDarts)
     {
-      BOOST_FOREACH( const boost::property_tree::ptree::value_type &v0,
+      for( const boost::property_tree::ptree::value_type &v0 :
                      pt.get_child("data.attributes") )
       {
         // <dimension>
@@ -734,14 +724,14 @@ namespace CGAL {
           {
             unsigned int id_dart_cellule=0;
             
-            BOOST_FOREACH(const boost::property_tree::ptree::value_type &v1,
+            for(const boost::property_tree::ptree::value_type &v1 :
                           v0.second )
             {
               if( v1.first == "a" )
               {
                 id_dart_cellule=v1.second.get<unsigned int>("d")-1;
                 
-                if (amap.template attribute<i>(myDarts[id_dart_cellule])==NULL)
+                if (amap.template attribute<i>(myDarts[id_dart_cellule])==nullptr)
                   amap.template set_attribute<i>
                     (myDarts[id_dart_cellule],
                    amap.template create_attribute<i>());
@@ -777,7 +767,7 @@ namespace CGAL {
     using boost::property_tree::ptree;
 
     // make darts
-    BOOST_FOREACH( const ptree::value_type &v, pt.get_child("data.darts") )
+    for( const ptree::value_type &v : pt.get_child("data.darts") )
     {
       if( v.first == "d" )
         myDarts.push_back(amap.create_dart());
@@ -788,11 +778,11 @@ namespace CGAL {
     unsigned int currentDartInt = 0;
     unsigned int nextDartInt;
 
-    BOOST_FOREACH( const ptree::value_type &v, pt.get_child("data.darts") )
+    for( const ptree::value_type &v : pt.get_child("data.darts") )
     {
       if( v.first == "d" )
       {
-        BOOST_FOREACH( const ptree::value_type &v2, v.second )
+        for( const ptree::value_type &v2 : v.second )
         {
           if (v2.first == "b")
           {
