@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Triangulation_2/include/CGAL/Constrained_triangulation_2.h $
-// $Id: Constrained_triangulation_2.h 4bb714f %aI Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Triangulation_2/include/CGAL/Constrained_triangulation_2.h $
+// $Id: Constrained_triangulation_2.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Mariette Yvinec, Jean-Daniel Boissonnat
@@ -120,6 +111,7 @@ public:
                                  typename Triangulation::All_edges_iterator>
                                                      Constrained_edges_iterator;
 
+  typedef Iterator_range<Constrained_edges_iterator> Constrained_edges;
 
 #ifndef CGAL_CFG_USING_BASE_MEMBER_BUG_2
   using Triangulation::number_of_vertices;
@@ -144,6 +136,11 @@ public:
   using Triangulation::includes_edge;
   using Triangulation::remove_first;
   using Triangulation::remove_second;
+  using Triangulation::is_valid;
+  using Triangulation::all_edges_begin;
+  using Triangulation::all_edges_end;
+  using Triangulation::mirror_index;
+  using Triangulation::orientation;
 #endif
 
   typedef Gt                                 Geom_traits;
@@ -178,7 +175,7 @@ public:
     for( ;lcit != lc.end(); lcit++) {
       insert( (*lcit).first, (*lcit).second);
     }
-     CGAL_triangulation_postcondition( this->is_valid() );
+     CGAL_triangulation_postcondition( is_valid() );
   }
 
   template<class InputIterator>
@@ -190,7 +187,7 @@ public:
     for ( ; it != last; it++) {
       	insert_constraint((*it).first, (*it).second);
       }
-      CGAL_triangulation_postcondition( this->is_valid() );
+      CGAL_triangulation_postcondition( is_valid() );
   }
 
   //TODO Is that destructor correct ?
@@ -201,18 +198,23 @@ public:
   {
     Is_constrained pred(*this);
     return Constrained_edges_iterator(pred,
-                                      this->all_edges_begin(),
-                                      this->all_edges_end());
+                                      all_edges_begin(),
+                                      all_edges_end());
   }
 
   Constrained_edges_iterator constrained_edges_end() const
   {
     Is_constrained pred(*this);
     return Constrained_edges_iterator(pred,
-                                      this->all_edges_end(),
-                                      this->all_edges_end());
+                                      all_edges_end(),
+                                      all_edges_end());
   }
 
+  Constrained_edges constrained_edges() const
+  {
+    return Constrained_edges(constrained_edges_begin(),constrained_edges_end());
+  }
+  
   // INSERTION
   Vertex_handle insert(const Point& p, 
 			       Face_handle start = Face_handle() );
@@ -588,7 +590,7 @@ public:
       fc->set_constraint(cw(vindex), false);
       fc->set_constraint(ccw(vindex), false);
       fh = fc->neighbor(vindex);
-      ih = this->mirror_index(fc,vindex);
+      ih = mirror_index(fc,vindex);
       fc->set_constraint(vindex, fh->is_constrained(ih));
     } while (++fc != done);
     return v;
@@ -806,7 +808,7 @@ find_intersected_faces(Vertex_handle vaa,
   // loop over triangles intersected by ab
   bool done = false;
   while (current_vertex != vbb && !done)  { 
-    orient = this->orientation(aa,bb,current_vertex->point());
+    orient = orientation(aa,bb,current_vertex->point());
     int i1, i2;
     switch (orient) {
     case COLLINEAR :  
@@ -993,7 +995,7 @@ update_constraints_incident(Vertex_handle va,
 {
   if (dimension() == 0) return;
   if (dimension()== 1) {
-    Edge_circulator ec=this->incident_edges(va), done(ec);
+    Edge_circulator ec=incident_edges(va), done(ec);
     do {
       ((*ec).first)->set_constraint(2,true);
     }while (++ec != done);
@@ -1001,7 +1003,7 @@ update_constraints_incident(Vertex_handle va,
   else{
     //dimension() ==2
     int cwi, ccwi, indf;
-    Face_circulator fc=this->incident_faces(va), done(fc);  
+    Face_circulator fc=incident_faces(va), done(fc);  
     CGAL_triangulation_assertion(fc != 0);
     do {
       indf = fc->index(va);
@@ -1026,7 +1028,7 @@ Constrained_triangulation_2<Gt,Tds,Itag>::
 clear_constraints_incident(Vertex_handle va)
 // make the edges incident to a newly created vertex unconstrained
 {
- Edge_circulator ec=this->incident_edges(va), done(ec);
+ Edge_circulator ec=incident_edges(va), done(ec);
  Face_handle f;
  int indf;
   if ( ec != 0){
@@ -1035,7 +1037,7 @@ clear_constraints_incident(Vertex_handle va)
       indf = (*ec).second;
       f->set_constraint(indf,false);
       if (dimension() == 2) {
-	f->neighbor(indf)->set_constraint(this->mirror_index(f,indf),false);
+	f->neighbor(indf)->set_constraint(mirror_index(f,indf),false);
       }
     } while (++ec != done);
   }
@@ -1055,7 +1057,7 @@ update_constraints_opposite(Vertex_handle va)
   int indf;
   do {
     indf = f->index(va);
-    if (f->neighbor(indf)->is_constrained(this->mirror_index(f,indf)) ) {
+    if (f->neighbor(indf)->is_constrained(mirror_index(f,indf)) ) {
       f->set_constraint(indf,true);
     }
     else {
@@ -1078,8 +1080,8 @@ update_constraints( const List_edges &hole)
     f =(*it).first;
     i = (*it).second;
     if ( f->is_constrained(i) ) 
-      (f->neighbor(i))->set_constraint(this->mirror_index(f,i),true);
-    else (f->neighbor(i))->set_constraint(this->mirror_index(f,i),false);
+      (f->neighbor(i))->set_constraint(mirror_index(f,i),true);
+    else (f->neighbor(i))->set_constraint(mirror_index(f,i),false);
   }
 }
 
@@ -1092,7 +1094,7 @@ mark_constraint(Face_handle fr, int i)
   if (dimension()==1) fr->set_constraint(2, true);
   else{
     fr->set_constraint(i,true);
-    fr->neighbor(i)->set_constraint(this->mirror_index(fr,i),true);
+    fr->neighbor(i)->set_constraint(mirror_index(fr,i),true);
   }
   return;
 }
@@ -1206,7 +1208,7 @@ remove_constrained_edge(Face_handle f, int i)
 {
   f->set_constraint(i, false);
   if (dimension() == 2)
-    (f->neighbor(i))->set_constraint(this->mirror_index(f,i), false);
+    (f->neighbor(i))->set_constraint(mirror_index(f,i), false);
   return;
 }
 
@@ -1291,28 +1293,28 @@ triangulate_half_hole(List_edges & list_edges,  List_edges & new_edges)
       // in case n1 is no longer a triangle of the new triangulation
       if ( n1->neighbor(ind1) != Face_handle() ) {
 	n=n1->neighbor(ind1);
-	//ind=this->mirror_index(n1,ind1); 
+	//ind=mirror_index(n1,ind1); 
 	// mirror_index does not work in this case
 	ind = cw(n->index(n1->vertex(cw(ind1))));
 	n1=n->neighbor(ind); 
-	ind1= this->mirror_index(n,ind);
+	ind1= mirror_index(n,ind);
       }
       n2=(*next).first;
       ind2=(*next).second;
       // in case n2 is no longer a triangle of the new triangulation
       if (n2->neighbor(ind2) != Face_handle() ) {
 	n=n2->neighbor(ind2); 
-	// ind=this->mirror_index(n2,ind2);
+	// ind=mirror_index(n2,ind2);
 	// mirror_index does not work in this case
 	ind = cw(n->index(n2->vertex(cw(ind2))));
 	n2=n->neighbor(ind); 
-	ind2= this->mirror_index(n,ind);
+	ind2= mirror_index(n,ind);
       }
 
       Vertex_handle v0=n1->vertex(ccw(ind1));
       Vertex_handle v1=n1->vertex(cw(ind1));
       Vertex_handle v2=n2->vertex(cw(ind2));
-      orient = this->orientation(v0->point(),v1->point(),v2->point());
+      orient = orientation(v0->point(),v1->point(),v2->point());
       switch (orient) {
       case RIGHT_TURN : 	  		
 	// creates the new triangle v0v1v2
