@@ -1,20 +1,11 @@
 // Copyright (c) 2004-2008 Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Curve_renderer_internals.h $
-// $Id: Curve_renderer_internals.h ff26773 %aI Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Curve_renderer_internals.h $
+// $Id: Curve_renderer_internals.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Pavel Emeliyanenko <asm@mpi-sb.mpg.de>
 //
@@ -321,11 +312,11 @@ public:
     
     //! \brief evalutates a polynomial at certain x-coordinate
     static NT evaluate(const Poly_1& poly, const NT& x, 
-        bool *error_bounds_ = NULL)
+        bool *error_bounds_ = nullptr)
     {
         typename Renderer_traits::Extract_eval extract;
         int n = poly.degree()+1, m = (n-1)>>1, odd = n&1;
-        if(error_bounds_ != NULL)
+        if(error_bounds_ != nullptr)
             *error_bounds_ = false;
         if(n == 1)
             return extract(poly.lcoeff(), error_bounds_);
@@ -479,7 +470,7 @@ bool setup(const CGAL::Bbox_2& box_, int res_w_, int res_h_)
     pixel_w = (x_max - x_min) / res_w;
     pixel_h = (y_max - y_min) / res_h;
 
-    //srand(time(NULL));
+    //srand(time(nullptr));
     // from 0.1 to 0.5
     double rmin = 0.1, rmax = 0.5;
     NT sx = pixel_w * static_cast<NT>(rmin + 
