@@ -5,20 +5,11 @@
 // Max-Planck-Institute Saarbruecken (Germany),
 // and Tel-Aviv University (Israel).  All rights reserved. 
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/HalfedgeDS/include/CGAL/HalfedgeDS_vector.h $
-// $Id: HalfedgeDS_vector.h 095c27e %aI Laurent Rineau
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/HalfedgeDS/include/CGAL/HalfedgeDS_vector.h $
+// $Id: HalfedgeDS_vector.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Lutz Kettner  <kettner@mpi-sb.mpg.de>
@@ -66,20 +57,10 @@ public:
     typedef typename Vertex_wrapper::Vertex            Vertex;
     typedef typename Halfedge_wrapper::Halfedge        Halfedge;
     typedef typename Face_wrapper::Face                Face;
-#ifdef CGAL_CXX11
     typedef std::allocator_traits<Allocator> Allocator_traits;
     typedef typename Allocator_traits::template rebind_alloc<Vertex> Vertex_allocator;
     typedef typename Allocator_traits::template rebind_alloc<Halfedge> Halfedge_allocator;
     typedef typename Allocator_traits::template rebind_alloc<Face> Face_allocator;
-#else // not CGAL_CXX11
-    typedef typename Allocator::template rebind< Vertex> Vertex_alloc_rebind;
-    typedef typename Vertex_alloc_rebind::other        Vertex_allocator;
-    typedef typename Allocator::template rebind< Halfedge>
-                                                       Halfedge_alloc_rebind;
-    typedef typename Halfedge_alloc_rebind::other      Halfedge_allocator;
-    typedef typename Allocator::template rebind< Face> Face_alloc_rebind;
-    typedef typename Face_alloc_rebind::other          Face_allocator;
-#endif // not CGAL_CXX11
 
 #ifdef CGAL__HALFEDGEDS_USE_INTERNAL_VECTOR
     typedef internal::vector<Vertex, Vertex_allocator> Vertex_vector;
@@ -490,7 +471,7 @@ public:
         // number of border halfedges. An edge with no incident face
         // counts as two border halfedges. Precondition: `normalize_border()'
         // has been called and no halfedge insertion or removal and no
-        // change in border status of the halfedges have occured since
+        // change in border status of the halfedges have occurred since
         // then.
 
     size_type size_of_border_edges() const { return nb_border_edges;}
@@ -499,7 +480,7 @@ public:
         // face on one side and to a hole on the other side.
         // Precondition: `normalize_border()' has been called and no
         // halfedge insertion or removal and no change in border status of
-        // the halfedges have occured since then.
+        // the halfedges have occurred since then.
 
     Halfedge_iterator border_halfedges_begin() {
         // halfedge iterator starting with the border edges. The range [
@@ -508,7 +489,7 @@ public:
         // halfedges_end()') denotes all border edges. Precondition:
         // `normalize_border()' has been called and no halfedge insertion
         // or removal and no change in border status of the halfedges have
-        // occured since then.
+        // occurred since then.
         return border_halfedges;
     }
 
@@ -534,14 +515,8 @@ public:
             return;
 
         // An array of pointers to update the changed halfedge pointers.
-#ifdef CGAL_CXX11
         typedef std::allocator_traits<Allocator> Allocator_traits;
         typedef typename Allocator_traits::template rebind_alloc<Halfedge_I> HI_allocator;
-#else
-        typedef typename Allocator::template rebind< Halfedge_I>
-                                                      HI_alloc_rebind;
-        typedef typename HI_alloc_rebind::other       HI_allocator;
-#endif
         typedef std::vector<Halfedge_I, HI_allocator> HVector;
         typedef typename HVector::iterator Hiterator;
         HVector hvector;
