@@ -1,21 +1,11 @@
 // Copyright (c) 2005-2008 ASCLEPIOS Project, INRIA Sophia-Antipolis (France)
 // All rights reserved.
 //
-// This file is part of the ImageIO Library, and as been adapted for
-// CGAL (www.cgal.org).
-// You can redistribute it and/or  modify it under the terms of the
-// GNU Lesser General Public License as published by the Free Software Foundation;
-// either version 3 of the License, or (at your option) any later version.
+// This file is part of the ImageIO Library, and as been adapted for CGAL (www.cgal.org).
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// These files are provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/CGAL_ImageIO/include/CGAL/ImageIO/gis_impl.h $
-// $Id: gis_impl.h 0698f79 %aI Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/CGAL_ImageIO/include/CGAL/ImageIO/gis_impl.h $
+// $Id: gis_impl.h 07c4ada 2019-10-19T15:50:09+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later
 //
 //
 // Author(s)     :  ASCLEPIOS Project (INRIA Sophia-Antipolis), Laurent Rineau
@@ -78,16 +68,16 @@ int writeGis( char *name, _image* im) {
   _openWriteImage(im, outputName);
   if( !im->fd ) {
     fprintf(stderr, "writeGis: error: unable to open file \'%s\'\n", outputName);
-    if ( outputName != NULL ) ImageIO_free( outputName );
+    if ( outputName != nullptr ) ImageIO_free( outputName );
     return ImageIO_OPENING;
   }
 
   if ( !writeGisHeader(im) ) {
     fprintf(stderr, "writeGis: error: unable to write header of \'%s\'\n",
 	    outputName);
-    if ( outputName != NULL ) ImageIO_free( outputName );
+    if ( outputName != nullptr ) ImageIO_free( outputName );
     ImageIO_close( im );
-    im->fd = NULL;
+    im->fd = nullptr;
     im->openMode = OM_CLOSE;
     return -1;
   }
@@ -106,7 +96,7 @@ int writeGis( char *name, _image* im) {
 
   if( !im->fd ) {
     fprintf(stderr, "writeGis: error: unable to open file \'%s\'\n", outputName);
-    if ( outputName != NULL ) ImageIO_free( outputName );
+    if ( outputName != nullptr ) ImageIO_free( outputName );
     return ImageIO_OPENING;
   }
 
@@ -120,19 +110,19 @@ int writeGis( char *name, _image* im) {
     switch( im->wordKind ) {
     default :
       fprintf(stderr, "writeGis: such word kind not handled in ascii mode for file \'%s\'\n", outputName);
-      if ( outputName != NULL ) ImageIO_free( outputName );
+      if ( outputName != nullptr ) ImageIO_free( outputName );
       return( -3 );
     case WK_FIXED :
       switch ( im->wdim ) {
       default :
 	fprintf(stderr, "writeGis: such word dim not handled in ascii mode for file \'%s\'\n", outputName);
-	if ( outputName != NULL ) ImageIO_free( outputName );
+	if ( outputName != nullptr ) ImageIO_free( outputName );
 	return( -3 );
       case 1 :
 	switch ( im->sign ) {
 	default :
 	  fprintf(stderr, "writeGis: such sign not handled in ascii mode for file \'%s\'\n", outputName);
-	  if ( outputName != NULL ) ImageIO_free( outputName );
+	  if ( outputName != nullptr ) ImageIO_free( outputName );
 	  return( -3 );
 	case SGN_UNSIGNED :
 	  {
@@ -148,7 +138,7 @@ int writeGis( char *name, _image* im) {
               res = (done == strlen( str )) ? int(done) : -1;
 	      if ( res  <= 0 ) {
 		fprintf(stderr, "writeGis: error when writing data in \'%s\'\n", outputName);
-		if ( outputName != NULL ) ImageIO_free( outputName );
+		if ( outputName != nullptr ) ImageIO_free( outputName );
 		return( -3 );
 	      }
 	    } while ( i < size );
@@ -168,7 +158,7 @@ int writeGis( char *name, _image* im) {
               res = (done == strlen( str )) ? int(done) : -1;
 	      if ( res  <= 0 ) {
 		fprintf(stderr, "writeGis: error when writing data in \'%s\'\n", outputName);
-		if ( outputName != NULL ) ImageIO_free( outputName );
+		if ( outputName != nullptr ) ImageIO_free( outputName );
 		return( -3 );
 	      }
 	    } while ( i < size );
@@ -180,7 +170,7 @@ int writeGis( char *name, _image* im) {
 	switch ( im->sign ) {
 	default :
 	  fprintf(stderr, "writeGis: such sign not handled in ascii mode for file \'%s\'\n", outputName);
-	  if ( outputName != NULL ) ImageIO_free( outputName );
+	  if ( outputName != nullptr ) ImageIO_free( outputName );
 	  return( -3 );
 	case SGN_UNSIGNED :
 	  {
@@ -196,7 +186,7 @@ int writeGis( char *name, _image* im) {
               res = (done == strlen( str )) ? int(done) : -1;
 	      if ( res  <= 0 ) {
 		fprintf(stderr, "writeGis: error when writing data in \'%s\'\n", outputName);
-		if ( outputName != NULL ) ImageIO_free( outputName );
+		if ( outputName != nullptr ) ImageIO_free( outputName );
 		return( -3 );
 	      }
 	    } while ( i < size );
@@ -216,7 +206,7 @@ int writeGis( char *name, _image* im) {
               res = (done == strlen( str )) ? int(done) : -1;
 	      if ( res  <= 0 ) {
 		fprintf(stderr, "writeGis: error when writing data in \'%s\'\n", outputName);
-		if ( outputName != NULL ) ImageIO_free( outputName );
+		if ( outputName != nullptr ) ImageIO_free( outputName );
 		return( -3 );
 	      }
 	    } while ( i < size );
@@ -228,12 +218,12 @@ int writeGis( char *name, _image* im) {
     } /* end of switch( im->wordKind ) */
 
     ImageIO_free( str ); 
-    if (outputName != NULL) ImageIO_free(outputName);
+    if (outputName != nullptr) ImageIO_free(outputName);
     return static_cast<int>(res);
   }
   else {
     bool ret = _writeInrimageData(im);
-    if (outputName != NULL) ImageIO_free(outputName);
+    if (outputName != nullptr) ImageIO_free(outputName);
     return (ret ? 1 : -1);
   }
 }
@@ -254,7 +244,7 @@ int testGisHeader(char *,const char *name) {
 CGAL_INLINE_FUNCTION
 int readGisHeader( const char* name,_image* im)
 {
-  char *s, *str = NULL;
+  char *s, *str = nullptr;
   int status;
   int n=0, nusermax = 20;
 
@@ -286,7 +276,7 @@ int readGisHeader( const char* name,_image* im)
 #define ADD_USER_STRING { \
     if ( n == 0 ) { \
       im->user = (char**)ImageIO_alloc( nusermax * sizeof( char*) ); \
-      for ( n=0; n<nusermax; n++ ) im->user[n] = NULL; \
+      for ( n=0; n<nusermax; n++ ) im->user[n] = nullptr; \
       n = 0; \
     } \
     im->user[n] = (char*)ImageIO_alloc( 1+strlen( s ) ); \
@@ -472,7 +462,7 @@ int readGisHeader( const char* name,_image* im)
 
 
   /* header is read. close header file and open data file. */
-  if( name != NULL ) {
+  if( name != nullptr ) {
     
     std::size_t length = strlen(name) ;
     char* data_filename = (char *) ImageIO_alloc(length+4) ;
@@ -554,14 +544,14 @@ int readGisHeader( const char* name,_image* im)
 	    ret = sscanf( tmp, "%d", &iv );
 	  break;
 	  default :
-	    ImageIO_free( im->data ); im->data = NULL;
+	    ImageIO_free( im->data ); im->data = nullptr;
 	    ImageIO_free( str );
 	    return -1;
 	  }
 	  
 	  if ( ret != 1 ) {
 	    fprintf( stderr, "readGisHeader: error in reading ascii data\n" );
-	    ImageIO_free( im->data ); im->data = NULL;
+	    ImageIO_free( im->data ); im->data = nullptr;
 	    ImageIO_free( str );
 	    return -1;	
 	  }
@@ -607,7 +597,7 @@ int readGisHeader( const char* name,_image* im)
 	    n ++;
 	  }
 	  else {
-	    ImageIO_free( im->data ); im->data = NULL;
+	    ImageIO_free( im->data ); im->data = nullptr;
 	    ImageIO_free( str );
 	    return -1;
 	  }
