@@ -5,20 +5,11 @@
 // Max-Planck-Institute Saarbruecken (Germany),
 // and Tel-Aviv University (Israel).  All rights reserved. 
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/STL_Extension/include/CGAL/In_place_list.h $
-// $Id: In_place_list.h cd7ae28 %aI Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/STL_Extension/include/CGAL/In_place_list.h $
+// $Id: In_place_list.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch>
@@ -59,7 +50,7 @@ template < class T >
 class In_place_list_base {
 public:
   In_place_list_base()
-    : next_link(NULL), prev_link(NULL)
+    : next_link(nullptr), prev_link(nullptr)
   {}
 
   T* next_link;        // forward pointer
@@ -243,19 +234,11 @@ public:
   // to T, T*, const T*, T&, const T&, size_t, and ptrdiff_t, respectively.
   // So we don't pass these types to the iterators explicitly.
 
-#ifdef CGAL_CXX11
   typedef typename std::allocator_traits<Allocator>::value_type            value_type;
   typedef typename std::allocator_traits<Allocator>::pointer               pointer;
   typedef typename std::allocator_traits<Allocator>::const_pointer         const_pointer;
   typedef typename std::allocator_traits<Allocator>::size_type             size_type;
   typedef typename std::allocator_traits<Allocator>::difference_type       difference_type;
-#else
-  typedef typename Allocator::value_type          value_type;
-  typedef typename Allocator::pointer             pointer;
-  typedef typename Allocator::const_pointer       const_pointer;
-  typedef typename Allocator::size_type           size_type;
-  typedef typename Allocator::difference_type     difference_type;
-#endif
 
   typedef value_type&       reference;
   typedef const value_type& const_reference;
@@ -287,11 +270,7 @@ protected:
   pointer get_node( const T& t) {
     pointer p = allocator.allocate(1);
 #ifdef CGAL_USE_ALLOCATOR_CONSTRUCT_DESTROY
-#ifdef CGAL_CXX11
     std::allocator_traits<Allocator>::construct(allocator, p, t);
-#else
-    allocator.construct(p, t);
-    #endif
 #else
     new (p) value_type(t);
 #endif
@@ -299,11 +278,7 @@ protected:
   }
   void put_node( pointer p) {
 #ifdef CGAL_USE_ALLOCATOR_CONSTRUCT_DESTROY  
-#  ifdef CGAL_CXX11
     std::allocator_traits<Allocator>::destroy(allocator, p);
-#  else
-    allocator.destroy( p);
-#  endif
 #else // not CGAL_USE_ALLOCATOR_CONSTRUCT_DESTROY
    p->~value_type();
 #endif
