@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Interval_skip_list/include/CGAL/Interval_skip_list.h $
-// $Id: Interval_skip_list.h f0c1d3a %aI Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Interval_skip_list/include/CGAL/Interval_skip_list.h $
+// $Id: Interval_skip_list.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Andreas Fabri
@@ -120,7 +111,7 @@ class Interval_for_container : public Interval_
       void * p;
     public:
       Interval_for_container(const Interval_& i)
-	: Interval_(i), p(NULL)
+	: Interval_(i), p(nullptr)
       {}
       
       void *   for_compact_container() const { return p; }
@@ -384,11 +375,7 @@ class Interval_for_container : public Interval_
       return it;
 #else
       IntervalListElt<Interval> *elt_ptr = alloc.allocate(1);
-#ifdef CGAL_CXX11
       std::allocator_traits<Alloc>::construct(alloc,elt_ptr, I);
-#else      
-      alloc.construct(elt_ptr, I);
-#endif
       return elt_ptr;
       //return new IntervalListElt<Interval>(I);
 #endif
@@ -400,11 +387,7 @@ class Interval_for_container : public Interval_
       compact_container.erase(I);
 #else
 
-#ifdef CGAL_CXX11
       std::allocator_traits<Alloc>::destroy(alloc,I);
-#else
-      alloc.destroy(I);
-#endif
       alloc.deallocate(I,1);
       //delete I;
 #endif
@@ -422,7 +405,7 @@ class Interval_for_container : public Interval_
     copy(OutputIterator out) const
     {
       ILE_handle e = header;
-      while(e!= NULL) { 
+      while(e!= nullptr) { 
 	out = *(e->I);
 	++out;
 	e = e->next;
@@ -627,7 +610,7 @@ template <class Interval>
   void IntervalList<Interval>::copy(IntervalList* from)
   {
     ILE_handle e = from->header;
-    while(e!=NULL) { 
+    while(e!=nullptr) { 
       insert(e->I);
       e = e->next;
     }
@@ -639,7 +622,7 @@ template <class Interval>
   {
     ILE_handle x = header;
     ILE_handle y; 
-    while(x!= NULL) { // was 0
+    while(x!= nullptr) { // was 0
       y = x;
       x = x->next;
       erase_list_element(y);
@@ -717,7 +700,7 @@ template <class Interval>
 
     for(i=0; (i<= x->level() - 2) && x->forward[i+1]!=0; i++) {
       IntervalList<Interval>* markList = update[i]->markers[i];
-      for(m = markList->get_first(); m != NULL ; m = markList->get_next(m)) {
+      for(m = markList->get_first(); m != nullptr ; m = markList->get_next(m)) {
 	if(m->getInterval()->contains_interval(x->key,x->forward[i+1]->key)) { 
 	  // promote m
 	  
@@ -735,7 +718,7 @@ template <class Interval>
 	}
       }
       
-      for(m = promoted.get_first(); m != NULL; m = promoted.get_next(m)) {
+      for(m = promoted.get_first(); m != nullptr; m = promoted.get_next(m)) {
 	if(!m->getInterval()->contains_interval(x->key, x->forward[i+1]->key)){
 	  // Then m does not need to be promoted higher.
 	  // Place m on the level i edge out of x and remove m from promoted.
@@ -765,7 +748,7 @@ template <class Interval>
     
     x->markers[i]->copy(&promoted);
     x->markers[i]->copy(update[i]->markers[i]);
-    for(m=promoted.get_first(); m!=NULL; m=promoted.get_next(m))
+    for(m=promoted.get_first(); m!=nullptr; m=promoted.get_next(m))
       if(m->getInterval()->contains(x->forward[i]->key))
         x->forward[i]->eqMarkers->insert(m->getInterval());
     
@@ -779,7 +762,7 @@ template <class Interval>
     for (i=0; (i <= x->level() - 2) && !update[i+1]->isHeader(); i++) {
       tempMarkList.copy(update[i]->markers[i]);
       for(m = tempMarkList.get_first(); 
-	  m != NULL; 
+	  m != nullptr; 
 	  m = tempMarkList.get_next(m)){
 	if(m->getInterval()->contains_interval(update[i+1]->key,x->key)) {
 	  // m needs to be promoted
@@ -794,7 +777,7 @@ template <class Interval>
       }
       tempMarkList.clear();  // reclaim storage
       
-      for(m = promoted.get_first(); m != NULL; m = promoted.get_next(m)) {
+      for(m = promoted.get_first(); m != nullptr; m = promoted.get_next(m)) {
 	if (!update[i]->isHeader() && 
 	    m->getInterval()->contains_interval(update[i]->key,x->key) &&
 	    !update[i+1]->isHeader() &&
@@ -837,12 +820,12 @@ template <class Interval>
        will be placed on the edge.  */
 
     update[i]->markers[i]->copy(&promoted);
-    for(m=promoted.get_first(); m!=NULL; m=promoted.get_next(m))
+    for(m=promoted.get_first(); m!=nullptr; m=promoted.get_next(m))
       if(m->getInterval()->contains(update[i]->key))
 	update[i]->eqMarkers->insert(m->getInterval());
 
     // Place markers on x for all intervals the cross x.
-    // (Since x is a new node, every marker comming into x must also leave x).
+    // (Since x is a new node, every marker coming into x must also leave x).
     for(i=0; i<x->level(); i++)
       x->eqMarkers->copy(x->markers[i]);
     
@@ -869,7 +852,7 @@ template <class Interval>
 
     for(i=x->level()-1; i>=0; i--){
       // find marks on edge into x at level i to be demoted
-      for(m=update[i]->markers[i]->get_first(); m!=NULL; 
+      for(m=update[i]->markers[i]->get_first(); m!=nullptr; 
 	  m=update[i]->markers[i]->get_next(m)){
 	if(x->forward[i]==0 ||
 	   ! m->getInterval()->contains_interval(update[i]->key,
@@ -883,7 +866,7 @@ template <class Interval>
       // there before demotion must be there afterwards.
 
       // Place previously demoted marks on this level as needed.
-      for(m=demoted.get_first(); m!=NULL; m=demoted.get_next(m)){
+      for(m=demoted.get_first(); m!=nullptr; m=demoted.get_next(m)){
 	// Place mark on level i from update[i+1] to update[i], not including 
 	// update[i+1] itself, since it already has a mark if it needs one.
 	for(y=update[i+1]; y!=0 && y!=update[i]; y=y->forward[i]) {
@@ -917,7 +900,7 @@ template <class Interval>
     // newDemoted is already empty
 
     for(i=x->level()-1; i>=0; i--){
-      for(m=x->markers[i]->get_first(); m!=NULL ; m=x->markers[i]->get_next(m)){
+      for(m=x->markers[i]->get_first(); m!=nullptr ; m=x->markers[i]->get_next(m)){
 	if(x->forward[i]!=0 && 
 	   (update[i]->isHeader() ||
 	    !m->getInterval()->contains_interval(update[i]->key,
@@ -927,7 +910,7 @@ template <class Interval>
 	  }
       }
 
-      for(m=demoted.get_first(); m!= NULL; m=demoted.get_next(m)){
+      for(m=demoted.get_first(); m!= nullptr; m=demoted.get_next(m)){
 	// Place mark on level i from x->forward[i] to x->forward[i+1].
 	// Don't place a mark directly on x->forward[i+1] since it is already
 	// marked.
@@ -1018,10 +1001,10 @@ template <class Interval>
       }
     }
     x = x->forward[0];
-    if(x != NULL && (x->key == searchKey))
+    if(x != nullptr && (x->key == searchKey))
       return(x);
     else
-      return(NULL);
+      return(nullptr);
   }
 
   template <class Interval>
@@ -1237,10 +1220,10 @@ template <class Interval>
     for(i=0; i<=topLevel; i++)
       {
 	os << "forward[" << i << "] = ";
-	if(forward[i] != NULL) {
+	if(forward[i] != nullptr) {
 	  os << forward[i]->getValue();
 	} else {
-	  os << "NULL";
+	  os << "nullptr";
 	}
 	os << std::endl;
       }
@@ -1248,10 +1231,10 @@ template <class Interval>
     for(i=0; i<=topLevel; i++)
       {
 	os << "markers[" << i << "] = ";
-	if(markers[i] != NULL) {
+	if(markers[i] != nullptr) {
 	  markers[i]->print(os);
 	} else {
-	  os << "NULL";
+	  os << "nullptr";
 	}
 	os << "\n";
       }
@@ -1276,14 +1259,14 @@ template <class Interval>
   IntervalList<Interval>::remove(const Interval& I, Interval_handle& res)
   {
     ILE_handle x, last;
-    x = header; last = NULL;
-    while(x != NULL && *(x->getInterval()) != I) {
+    x = header; last = nullptr;
+    while(x != nullptr && *(x->getInterval()) != I) {
       last = x;
       x = x->next;
     } 
-    if(x==NULL) {
+    if(x==nullptr) {
       return false;
-    } else if (last==NULL) {
+    } else if (last==nullptr) {
       header = x->next;
       res = x->getInterval();
       erase_list_element(x);
@@ -1301,14 +1284,14 @@ template <class Interval>
   IntervalList<Interval>::remove(const Interval& I)
   {
     ILE_handle x, last;
-    x = header; last = NULL;
-    while(x != NULL && *(x->getInterval()) != I) {
+    x = header; last = nullptr;
+    while(x != nullptr && *(x->getInterval()) != I) {
       last = x;
       x = x->next;
     }
-    if(x==NULL) {
+    if(x==nullptr) {
       return ;
-    } else if (last==NULL) {
+    } else if (last==nullptr) {
       header = x->next;
       erase_list_element(x);
     } else {
@@ -1321,7 +1304,7 @@ template <class Interval>
   void IntervalList<Interval>::removeAll(IntervalList<Interval> *l)
   {
     ILE_handle x;
-    for(x=l->get_first(); x!=NULL; x=l->get_next(x))
+    for(x=l->get_first(); x!=nullptr; x=l->get_next(x))
       this->remove(*(x->getInterval()));
   }
 
@@ -1329,14 +1312,14 @@ template <class Interval>
   template <class Interval>
   inline 
   IntervalListElt<Interval>::IntervalListElt()
-    : next(NULL)
+    : next(nullptr)
   {}
 
 
   template <class Interval>
   inline 
   IntervalListElt<Interval>::IntervalListElt(const Interval_handle& anInterval)
-    : I(anInterval), next(NULL)
+    : I(anInterval), next(nullptr)
   {}
 
   template <class Interval>
@@ -1366,7 +1349,7 @@ template <class Interval>
   void IntervalList<Interval>::print(std::ostream& os) const
   {
     ILE_handle e = header;
-    while(e != NULL) {
+    while(e != nullptr) {
       e->print(os);
       e = e->get_next();
     }
@@ -1377,7 +1360,7 @@ template <class Interval>
   {
     /*
     if(I == 0) {
-      os << "NULL";
+      os << "nullptr";
     } else {
       os << *I;
     }
@@ -1391,7 +1374,7 @@ template <class Interval>
     ILE_handle x = header;
     while(x!=0 && I != x->I)
       x = x->next;
-    if (x==NULL)
+    if (x==nullptr)
       return false;
     else
       return true;
@@ -1401,7 +1384,7 @@ template <class Interval>
 
   template <class Interval>
   inline IntervalList<Interval>::IntervalList()
-    :  header(NULL)
+    :  header(nullptr)
   {}
 
 
