@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Jet_fitting_3/include/CGAL/Monge_via_jet_fitting.h $
-// $Id: Monge_via_jet_fitting.h ee57fc2 %aI Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Jet_fitting_3/include/CGAL/Monge_via_jet_fitting.h $
+// $Id: Monge_via_jet_fitting.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Pouget and Frédéric Cazals
 #ifndef CGAL_MONGE_VIA_JET_FITTING_H_
@@ -32,10 +23,6 @@
 #include <utility>
 #ifdef CGAL_EIGEN3_ENABLED
 #include <CGAL/Eigen_svd.h>
-#else
-#ifdef CGAL_LAPACK_ENABLED
-#include <CGAL/Lapack_svd.h>
-#endif
 #endif
 
 namespace CGAL {
@@ -51,11 +38,7 @@ unsigned int fact(unsigned int n){
 #ifdef CGAL_EIGEN3_ENABLED
 template < class DataKernel, class LocalKernel = Simple_cartesian<double>, class SvdTraits = Eigen_svd >
 #else
-#ifdef CGAL_LAPACK_ENABLED
-template < class DataKernel, class LocalKernel = Simple_cartesian<double>, class SvdTraits = Lapack_svd>  
-#else
 template < class DataKernel, class LocalKernel, class SvdTraits >  
-#endif
 #endif
   class Monge_via_jet_fitting {
  public:
@@ -369,9 +352,9 @@ compute_PCA(InputIterator begin, InputIterator end)
   // 0 1 2
   //   3 4
   //     5
-  CGAL::cpp11::array<FT, 6> covariance = {{ xx,xy,xz,yy,yz,zz }};
-  CGAL::cpp11::array<FT, 3> eigen_values = {{ 0., 0., 0. }};
-  CGAL::cpp11::array<FT, 9> eigen_vectors = {{ 0., 0., 0. }};
+  std::array<FT, 6> covariance = {{ xx,xy,xz,yy,yz,zz }};
+  std::array<FT, 3> eigen_values = {{ 0., 0., 0. }};
+  std::array<FT, 9> eigen_vectors = {{ 0., 0., 0. }};
 
   // solve for eigenvalues and eigenvectors.
   // eigen values are sorted in ascending order, 
@@ -532,9 +515,9 @@ compute_Monge_basis(const FT* A, Monge_form& monge_form)
   weingarten = inv *(1/det) * weingarten * change_XuXv2YZ;
   
   // diagonalization of weingarten
-  CGAL::cpp11::array<FT,3> W = {{ weingarten(0,0), weingarten(1,0), weingarten(1,1) }};
-  CGAL::cpp11::array<FT,2> eval = {{ 0., 0. }};
-  CGAL::cpp11::array<FT,4> evec = {{ 0., 0., 0., 0. }};
+  std::array<FT,3> W = {{ weingarten(0,0), weingarten(1,0), weingarten(1,1) }};
+  std::array<FT,2> eval = {{ 0., 0. }};
+  std::array<FT,4> evec = {{ 0., 0., 0., 0. }};
 
   //eval in increasing order
   CGAL::Default_diagonalize_traits<FT,2>::diagonalize_selfadjoint_covariance_matrix
