@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESISGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Nef_3/include/CGAL/Nef_3/Binary_operation.h $
-// $Id: Binary_operation.h 8cdfad0 %aI Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Nef_3/include/CGAL/Nef_3/Binary_operation.h $
+// $Id: Binary_operation.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Michael Seel       <seel@mpi-sb.mpg.de>
@@ -287,7 +278,7 @@ class Binary_operation : public CGAL::SNC_decorator<Map> {
   {
     //    CGAL_NEF_SETDTHREAD(23);
     CGAL_assertion( this->sncp()->is_empty());
-    CGAL_assertion( pl1 != NULL && pl2 != NULL);
+    CGAL_assertion( pl1 != nullptr && pl2 != nullptr);
     //    CGAL_NEF_SETDTHREAD(19*13*43*37);
 
 #ifdef CGAL_NEF3_TIMER_BINARY_OPERATION
