@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESISGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Nef_3/include/CGAL/Nef_3/SNC_decorator.h $
-// $Id: SNC_decorator.h ee57fc2 %aI Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Nef_3/include/CGAL/Nef_3/SNC_decorator.h $
+// $Id: SNC_decorator.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Michael Seel    <seel@mpi-sb.mpg.de>
@@ -176,7 +167,7 @@ class SNC_decorator : public SNC_const_decorator<Map> {
     : Base(*(S.sncp_)), sncp_(S.sncp_) {}
 
   SNC_structure* sncp() const { 
-    CGAL_assertion( sncp_ != NULL);
+    CGAL_assertion( sncp_ != nullptr);
     return sncp_; 
   }
 
@@ -705,7 +696,7 @@ class SNC_decorator : public SNC_const_decorator<Map> {
 	SM_decorator S2(&*he->twin()->source());
 	SHalfedge_handle se1(S1.first_out_edge(he));
 	SHalfedge_handle se2(S2.first_out_edge(he->twin()));
-	if(se1 != NULL && se2 != NULL) {
+	if(se1 != nullptr && se2 != nullptr) {
 	  SHalfedge_handle start1(se1);
 	  SHalfedge_handle start2(se2->twin()->snext());
 	  while(se1->facet() != se2->twin()->facet() && se2 != start2)
@@ -777,7 +768,7 @@ class SNC_decorator : public SNC_const_decorator<Map> {
       CGAL_forall_shells_of(si,voli) {
 	//	valid = valid && (si != Shell_entry_iterator() &&
 	valid = valid && (SFace_handle(si) != SFace_handle() && 
-			  SFace_handle(si) != NULL);
+			  SFace_handle(si) != nullptr);
 	valid = valid && (++count <= max);
       }
       valid = valid && (++count <= max);
