@@ -2,25 +2,16 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Partition_2/include/CGAL/Partition_2/Matrix.h $
-// $Id: Matrix.h ee57fc2 %aI Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Partition_2/include/CGAL/Partition_2/Matrix.h $
+// $Id: Matrix.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Susan Hert <hert@mpi-sb.mpg.de>
 
-#ifndef   CGAL_MATRIX_H
-#define   CGAL_MATRIX_H
+#ifndef   CGAL_PARTITION_MATRIX_H
+#define   CGAL_PARTITION_MATRIX_H
 
 #include <CGAL/license/Partition_2.h>
 
@@ -67,4 +58,4 @@ std::ostream& operator<<(std::ostream& os, const Matrix<T>& m)
 
 }
 
-#endif // CGAL_MATRIX_H
+#endif // CGAL_PARTITION_MATRIX_H
