@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Periodic_2_triangulation_2/include/CGAL/Periodic_2_triangulation_iterators_2.h $
-// $Id: Periodic_2_triangulation_iterators_2.h ee57fc2 %aI Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Periodic_2_triangulation_2/include/CGAL/Periodic_2_triangulation_iterators_2.h $
+// $Id: Periodic_2_triangulation_iterators_2.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Nico Kruithof <Nico@nghk.nl>
 
@@ -67,7 +58,7 @@ public:
   typedef typename T::Iterator_type                       Iterator_type;
 
   Periodic_2_triangulation_triangle_iterator_2(Iterator_type it = T::STORED)
-    : _t(NULL), _it(it), _off(0) {}
+    : _t(nullptr), _it(it), _off(0) {}
 
   Periodic_2_triangulation_triangle_iterator_2(const T * t,
       Iterator_type it = T::STORED)
@@ -386,7 +377,7 @@ public:
   typedef typename T::Iterator_type                       Iterator_type;
 
   Periodic_2_triangulation_segment_iterator_2(Iterator_type it = T::STORED)
-    : _t(NULL), _it(it), _off(0) {}
+    : _t(nullptr), _it(it), _off(0) {}
 
   Periodic_2_triangulation_segment_iterator_2(const T * t,
       Iterator_type it = T::STORED)
@@ -682,7 +673,7 @@ public:
   typedef typename T::Iterator_type                       Iterator_type;
 
   Periodic_2_triangulation_point_iterator_2(Iterator_type it = T::STORED)
-    : _t(NULL), _it(it) {}
+    : _t(nullptr), _it(it) {}
 
   Periodic_2_triangulation_point_iterator_2(const T * t,
       Iterator_type it = T::STORED)
