@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Corefinement/intersection_impl.h $
-// $Id: intersection_impl.h d6ea587 %aI Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Corefinement/intersection_impl.h $
+// $Id: intersection_impl.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Sebastien Loriot
@@ -35,7 +26,6 @@
 #include <CGAL/Polygon_mesh_processing/internal/Corefinement/intersect_triangle_and_segment_3.h>
 #include <CGAL/utility.h>
 
-#include <boost/foreach.hpp>
 #include <boost/unordered_map.hpp>
 #include <boost/unordered_set.hpp>
 #include <boost/dynamic_bitset.hpp>
@@ -210,7 +200,7 @@ class Intersection_of_triangle_meshes
 
     face_boxes.reserve(num_faces(tm_f));
     face_boxes_ptr.reserve(num_faces(tm_f));
-    BOOST_FOREACH(face_descriptor fd, faces(tm_f))
+    for(face_descriptor fd : faces(tm_f))
     {
       halfedge_descriptor h=halfedge(fd,tm_f);
       face_boxes.push_back( Box(
@@ -223,7 +213,7 @@ class Intersection_of_triangle_meshes
 
     edge_boxes.reserve(num_edges(tm_e));
     edge_boxes_ptr.reserve(num_edges(tm_e));
-    BOOST_FOREACH(edge_descriptor ed, edges(tm_e))
+    for(edge_descriptor ed : edges(tm_e))
     {
       halfedge_descriptor h=halfedge(ed,tm_e);
       edge_boxes.push_back( Box(
@@ -275,7 +265,7 @@ class Intersection_of_triangle_meshes
 
     face_boxes.reserve(num_faces(tm));
     face_boxes_ptr.reserve(num_faces(tm));
-    BOOST_FOREACH(face_descriptor fd, faces(tm))
+    for(face_descriptor fd : faces(tm))
     {
       halfedge_descriptor h=halfedge(fd,tm);
       face_boxes.push_back( Box(
@@ -288,7 +278,7 @@ class Intersection_of_triangle_meshes
 
     edge_boxes.reserve(num_edges(tm));
     edge_boxes_ptr.reserve(num_edges(tm));
-    BOOST_FOREACH(edge_descriptor ed, edges(tm))
+    for(edge_descriptor ed : edges(tm))
     {
       halfedge_descriptor h=halfedge(ed,tm);
       edge_boxes.push_back( Box(
@@ -417,14 +407,14 @@ class Intersection_of_triangle_meshes
     {
       face_descriptor f_2 = face(edge_intersected, tm2);
       add_intersection_point_to_face_and_all_edge_incident_faces(f_2,e_1,tm2,tm1,node_id);
-      if (fset!=NULL) fset->erase(f_2);
+      if (fset!=nullptr) fset->erase(f_2);
     }
     edge_intersected = opposite(edge_intersected, tm2);
     if (!is_border(edge_intersected, tm2))
     {
       face_descriptor f_2 = face(edge_intersected, tm2);
       add_intersection_point_to_face_and_all_edge_incident_faces(f_2,e_1,tm2,tm1,node_id);
-      if (fset!=NULL) fset->erase(f_2);
+      if (fset!=nullptr) fset->erase(f_2);
     }
 
     //associate the intersection point to all faces incident to edge using the intersected edge
@@ -460,7 +450,7 @@ class Intersection_of_triangle_meshes
                               const TriangleMesh& tm1,
                               const TriangleMesh& tm2)
   {
-    BOOST_FOREACH(halfedge_descriptor h_2,
+    for(halfedge_descriptor h_2 :
                   halfedges_around_target(vertex_intersected,tm2))
     {
       cip_handle_case_edge(node_id,fset,edge,h_2,tm1,tm2);
@@ -481,7 +471,7 @@ class Intersection_of_triangle_meshes
                                          ? stm_edge_to_ltm_faces
                                          : ltm_edge_to_stm_faces;
 
-    BOOST_FOREACH(halfedge_descriptor h_1,
+    for(halfedge_descriptor h_1 :
                   halfedges_around_target(v_1,tm1))
     {
       add_intersection_point_to_face_and_all_edge_incident_faces(face(f_2,tm2),h_1,tm2,tm1,node_id);
@@ -504,11 +494,11 @@ class Intersection_of_triangle_meshes
                                          ? stm_edge_to_ltm_faces
                                          : ltm_edge_to_stm_faces;
 
-    BOOST_FOREACH(halfedge_descriptor h_1,
+    for(halfedge_descriptor h_1 :
                   halfedges_around_target(v_1,tm1))
     {
       typename Edge_to_faces::iterator it_ets=tm1_edge_to_tm2_faces.find(edge(h_1,tm1));
-      Face_set* fset = (it_ets!=tm1_edge_to_tm2_faces.end())?&(it_ets->second):NULL;
+      Face_set* fset = (it_ets!=tm1_edge_to_tm2_faces.end())?&(it_ets->second):nullptr;
       cip_handle_case_edge(node_id,fset,h_1,e_2,tm1,tm2);
     }
   }
@@ -527,11 +517,11 @@ class Intersection_of_triangle_meshes
                                          ? stm_edge_to_ltm_faces
                                          : ltm_edge_to_stm_faces;
 
-    BOOST_FOREACH(halfedge_descriptor h_1,
+    for(halfedge_descriptor h_1 :
                   halfedges_around_target(v_1,tm1))
     {
       typename Edge_to_faces::iterator it_ets=tm1_edge_to_tm2_faces.find(edge(h_1,tm1));
-      Face_set* fset = (it_ets!=tm1_edge_to_tm2_faces.end())?&(it_ets->second):NULL;
+      Face_set* fset = (it_ets!=tm1_edge_to_tm2_faces.end())?&(it_ets->second):nullptr;
       cip_handle_case_vertex(node_id,fset,h_1,v_2,tm1,tm2);
     }
   }
@@ -545,7 +535,7 @@ class Intersection_of_triangle_meshes
   {
     CGAL_assertion( &tm1 < &tm2 || &tm1==&tm2 );
 
-    typedef cpp11::tuple<Intersection_type,
+    typedef std::tuple<Intersection_type,
                          Intersection_type,
                          halfedge_descriptor,
                          halfedge_descriptor> Key;
@@ -553,7 +543,7 @@ class Intersection_of_triangle_meshes
     typedef std::map<Key,Node_id> Coplanar_node_map;
     Coplanar_node_map coplanar_node_map;
 
-    BOOST_FOREACH(const Face_pair& face_pair, coplanar_faces)
+    for(const Face_pair& face_pair : coplanar_faces)
     {
       face_descriptor f1=face_pair.first;
       face_descriptor f2=face_pair.second;
@@ -570,11 +560,11 @@ class Intersection_of_triangle_meshes
       std::size_t nb_pts=inter_pts.size();
       std::vector<Node_id> cpln_nodes; cpln_nodes.reserve(nb_pts);
 
-      BOOST_FOREACH(const Cpl_inter_pt& ipt, inter_pts)
+      for(const Cpl_inter_pt& ipt : inter_pts)
       {
         Node_id node_id;
         bool is_new_node;
-        cpp11::tie(node_id, is_new_node) =
+        std::tie(node_id, is_new_node) =
             get_or_create_node(ipt,current_node,coplanar_node_map,tm1,tm2);
         cpln_nodes.push_back(node_id);
 
@@ -606,7 +596,7 @@ class Intersection_of_triangle_meshes
               if(is_new_node)
                 visitor.new_node_added(node_id,ON_EDGE,ipt.info_1,ipt.info_2,tm1,tm2,false,false);
               typename Edge_to_faces::iterator it_ets=stm_edge_to_ltm_faces.find(edge(ipt.info_1,tm1));
-              Face_set* fset = (it_ets!=stm_edge_to_ltm_faces.end())?&(it_ets->second):NULL;
+              Face_set* fset = (it_ets!=stm_edge_to_ltm_faces.end())?&(it_ets->second):nullptr;
               cip_handle_case_edge(node_id,fset,ipt.info_1,ipt.info_2,tm1,tm2);
             }
             break;
@@ -652,14 +642,14 @@ class Intersection_of_triangle_meshes
                     const TriangleMesh& tm2,
                     const VertexPointMap& vpm1,
                     const VertexPointMap& vpm2,
-                    cpp11::tuple<Intersection_type,
+                    std::tuple<Intersection_type,
                                  halfedge_descriptor,
                                  bool,bool> inter_res)
   {
-    if ( cpp11::get<3>(inter_res) ) // is edge target in triangle plane
+    if ( std::get<3>(inter_res) ) // is edge target in triangle plane
       nodes.add_new_node(get(vpm1, target(h_1,tm1)));
     else{
-      if (cpp11::get<2>(inter_res)) // is edge source in triangle plane
+      if (std::get<2>(inter_res)) // is edge source in triangle plane
         nodes.add_new_node(get(vpm1, source(h_1,tm1)));
       else
         nodes.add_new_node(h_1,f_2,tm1,tm2,vpm1,vpm2);
@@ -673,7 +663,7 @@ class Intersection_of_triangle_meshes
                                    const VertexPointMap& vpm2,
                                    Node_id& current_node)
   {
-    typedef cpp11::tuple<Intersection_type, halfedge_descriptor, bool,bool>  Inter_type;
+    typedef std::tuple<Intersection_type, halfedge_descriptor, bool,bool>  Inter_type;
 
 
     for(typename Edge_to_faces::iterator it=tm1_edge_to_tm2_faces.begin();
@@ -686,16 +676,16 @@ class Intersection_of_triangle_meshes
         face_descriptor f_2=*fset.begin();
 
         Inter_type res=intersection_type(h_1,f_2,tm1,tm2,vpm1,vpm2);
-        Intersection_type type=cpp11::get<0>(res);
+        Intersection_type type=std::get<0>(res);
 
     //handle degenerate case: one extremity of edge belong to f_2
         std::vector<halfedge_descriptor> all_edges;
-        if ( cpp11::get<3>(res) ) // is edge target in triangle plane
+        if ( std::get<3>(res) ) // is edge target in triangle plane
           std::copy(halfedges_around_target(h_1,tm1).first,
                     halfedges_around_target(h_1,tm1).second,
                     std::back_inserter(all_edges));
         else{
-          if ( cpp11::get<2>(res) ) // is edge source in triangle plane
+          if ( std::get<2>(res) ) // is edge source in triangle plane
               std::copy(halfedges_around_source(h_1,tm1).first,
                         halfedges_around_source(h_1,tm1).second,
                         std::back_inserter(all_edges));
@@ -706,8 +696,8 @@ class Intersection_of_triangle_meshes
         CGAL_precondition(all_edges[0]==h_1 || all_edges[0]==opposite(h_1,tm1));
 
         // #ifdef USE_DETECTION_MULTIPLE_DEFINED_EDGES
-        // check_coplanar_edges(cpp11::next(all_edges.begin()),
-        //                      all_edges.end(),CGAL::cpp11::get<1>(res),type);
+        // check_coplanar_edges(std::next(all_edges.begin()),
+        //                      all_edges.end(),std::get<1>(res),type);
         // #endif
 
         typename std::vector<halfedge_descriptor>::iterator it_edge=all_edges.begin();
@@ -726,11 +716,11 @@ class Intersection_of_triangle_meshes
           // Case when the edge pierces the face in its interior.
           case ON_FACE:
           {
-            CGAL_assertion(f_2==face(cpp11::get<1>(res),tm2));
+            CGAL_assertion(f_2==face(std::get<1>(res),tm2));
 
             Node_id node_id=++current_node;
             add_new_node(h_1,f_2,tm1,tm2,vpm1,vpm2,res);
-            visitor.new_node_added(node_id,ON_FACE,h_1,halfedge(f_2,tm2),tm1,tm2,CGAL::cpp11::get<3>(res),CGAL::cpp11::get<2>(res));
+            visitor.new_node_added(node_id,ON_FACE,h_1,halfedge(f_2,tm2),tm1,tm2,std::get<3>(res),std::get<2>(res));
             for (;it_edge!=all_edges.end();++it_edge){
               add_intersection_point_to_face_and_all_edge_incident_faces(f_2,*it_edge,tm2,tm1,node_id);
               //erase face from the list to test intersection with it_edge
@@ -750,12 +740,12 @@ class Intersection_of_triangle_meshes
           {
             Node_id node_id=++current_node;
             add_new_node(h_1,f_2,tm1,tm2,vpm1,vpm2,res);
-            halfedge_descriptor h_2=cpp11::get<1>(res);
-            visitor.new_node_added(node_id,ON_EDGE,h_1,h_2,tm1,tm2,cpp11::get<3>(res),cpp11::get<2>(res));
+            halfedge_descriptor h_2=std::get<1>(res);
+            visitor.new_node_added(node_id,ON_EDGE,h_1,h_2,tm1,tm2,std::get<3>(res),std::get<2>(res));
             for (;it_edge!=all_edges.end();++it_edge){
               if ( it_edge!=all_edges.begin() ){
                 typename Edge_to_faces::iterator it_ets=tm1_edge_to_tm2_faces.find(edge(*it_edge,tm1));
-                Face_set* fset_bis = (it_ets!=tm1_edge_to_tm2_faces.end())?&(it_ets->second):NULL;
+                Face_set* fset_bis = (it_ets!=tm1_edge_to_tm2_faces.end())?&(it_ets->second):nullptr;
                 cip_handle_case_edge(node_id,fset_bis,*it_edge,h_2,tm1,tm2);
               }
               else
@@ -767,14 +757,14 @@ class Intersection_of_triangle_meshes
           case ON_VERTEX:
           {
             Node_id node_id=++current_node;
-            halfedge_descriptor h_2=cpp11::get<1>(res);
+            halfedge_descriptor h_2=std::get<1>(res);
             nodes.add_new_node(get(vpm2, target(h_2,tm2))); //we use the original vertex to create the node
             //before it was ON_FACE but do not remember why, probably a bug...
-            visitor.new_node_added(node_id,ON_VERTEX,h_1,h_2,tm1,tm2,cpp11::get<3>(res),cpp11::get<2>(res));
+            visitor.new_node_added(node_id,ON_VERTEX,h_1,h_2,tm1,tm2,std::get<3>(res),std::get<2>(res));
             for (;it_edge!=all_edges.end();++it_edge){
               if ( it_edge!=all_edges.begin() ){
                 typename Edge_to_faces::iterator it_ets=tm1_edge_to_tm2_faces.find(edge(*it_edge,tm1));
-                Face_set* fset_bis = (it_ets!=tm1_edge_to_tm2_faces.end())?&(it_ets->second):NULL;
+                Face_set* fset_bis = (it_ets!=tm1_edge_to_tm2_faces.end())?&(it_ets->second):nullptr;
                 cip_handle_case_vertex(node_id,fset_bis,*it_edge,h_2,tm1,tm2);
               }
               else
@@ -852,7 +842,7 @@ class Intersection_of_triangle_meshes
                          std::vector<Node_id> > map_to_process;
 
     typedef std::pair<const face_descriptor, std::vector<face_descriptor> > Pair_type;
-    BOOST_FOREACH(Pair_type& p, face_intersections)
+    for(Pair_type& p : face_intersections)
     {
       face_descriptor f1 = p.first;
       std::vector<face_descriptor>& inter_faces=p.second;
@@ -982,8 +972,8 @@ class Intersection_of_triangle_meshes
                   // with the point found.
                   typename Faces_to_nodes_map::iterator it_seg3 = find_it;
                   // first check if there is only one such edge (no test is needed then)
-                  if (cpp11::next(it_seg3)!=f_to_node.end() &&
-                      cpp11::next(it_seg3)->first.first == it_seg3->first.first)
+                  if (std::next(it_seg3)!=f_to_node.end() &&
+                      std::next(it_seg3)->first.first == it_seg3->first.first)
                   {
                     while(true)
                     {
@@ -1049,7 +1039,7 @@ class Intersection_of_triangle_meshes
 #endif
     typedef std::pair<const std::pair< std::pair<face_descriptor, face_descriptor>, int>,
                       std::vector<Node_id> > Faces_and_nodes;
-    BOOST_FOREACH(Faces_and_nodes& f_n_nids, map_to_process)
+    for(Faces_and_nodes& f_n_nids : map_to_process)
     {
       //get the original entry and remove it
       typename Faces_to_nodes_map::iterator find_it =
@@ -1072,7 +1062,7 @@ class Intersection_of_triangle_meshes
 #ifdef CGAL_DEBUG_AUTOREFINEMENT
       std::cout << n1 << " -> " << n2 << "\n";
 #endif
-      BOOST_FOREACH(Node_id id, f_n_nids.second)
+      for(Node_id id : f_n_nids.second)
       {
         insert_it = f_to_node.insert(insert_it, std::make_pair(
           std::make_pair(f_n_nids.first.first,--i), Node_id_set()) ); // I have picked negative int for refined edges
@@ -1115,7 +1105,7 @@ class Intersection_of_triangle_meshes
     // these nodes are created by pinchements along an edge of the surface.
     // the node ids being the same for the two edges, the degree of the node
     // in the graph is two while it should be 3
-    BOOST_FOREACH(Node_id id, extra_terminal_nodes)
+    for(Node_id id : extra_terminal_nodes)
       graph[id].make_terminal();
 
     //visitor call
@@ -1223,7 +1213,7 @@ class Intersection_of_triangle_meshes
         to_erase.push_back(it);
     }
 
-    BOOST_FOREACH(typename Faces_to_nodes_map::iterator it, to_erase)
+    for(typename Faces_to_nodes_map::iterator it : to_erase)
       f_to_node.erase(it);
   }
 
