@@ -4,19 +4,11 @@
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
  This file is part of a fork of the QGLViewer library version 2.7.0.
- http://www.libqglviewer.com - contact@libqglviewer.com
-
- This file may be used under the terms of the GNU General Public License 
- version 3.0 as published by the Free Software Foundation and
- appearing in the LICENSE file included in the packaging of this file.
-
- This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/GraphicsView/include/CGAL/Qt/frame_impl.h $
-// $Id: frame_impl.h 1df3c3e %aI Laurent Rineau
-// SPDX-License-Identifier: GPL-3.0
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/GraphicsView/include/CGAL/Qt/frame_impl.h $
+// $Id: frame_impl.h 1ef976e 2019-10-19T16:09:56+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-only
 
 #ifdef CGAL_HEADER_ONLY
 #define CGAL_INLINE_FUNCTION inline
@@ -39,9 +31,9 @@ namespace qglviewer{
 /*! Creates a default Frame.
 
   Its position() is (0,0,0) and it has an identity orientation() Quaternion. The
-  referenceFrame() and the constraint() are \c NULL. */
+  referenceFrame() and the constraint() are \c nullptr. */
 CGAL_INLINE_FUNCTION
-Frame::Frame() : constraint_(NULL), referenceFrame_(NULL) {}
+Frame::Frame() : constraint_(nullptr), referenceFrame_(nullptr) {}
 
 /*! Creates a Frame with a position() and an orientation().
 
@@ -49,10 +41,10 @@ Frame::Frame() : constraint_(NULL), referenceFrame_(NULL) {}
  methods.
 
  The Frame is defined in the world coordinate system (its referenceFrame() is \c
- NULL). It has a \c NULL associated constraint(). */
+ nullptr). It has a \c nullptr associated constraint(). */
 CGAL_INLINE_FUNCTION
 Frame::Frame(const Vec &position, const Quaternion &orientation)
-    : t_(position), q_(orientation), constraint_(NULL), referenceFrame_(NULL) {}
+    : t_(position), q_(orientation), constraint_(nullptr), referenceFrame_(nullptr) {}
 
 /*! Equal operator.
 
@@ -118,7 +110,7 @@ Frame::Frame(const Frame &frame) : QObject() { (*this) = frame; }
   This matrix only represents the local Frame transformation (i.e. with respect
   to the referenceFrame()). Use worldMatrix() to get the full Frame
   transformation matrix (i.e. from the world to the Frame coordinate system).
-  These two match when the referenceFrame() is \c NULL.
+  These two match when the referenceFrame() is \c nullptr.
 
   The result is only valid until the next call to matrix(), getMatrix(),
   worldMatrix() or getWorldMatrix(). Use it immediately (as above) or use
@@ -170,7 +162,7 @@ void Frame::getMatrix(GLdouble m[16]) const {
   Only the local Frame transformation (i.e. defined with respect to the
   referenceFrame()) is inverted. Use worldInverse() for a global inverse.
 
-  The resulting Frame has the same referenceFrame() as the Frame and a \c NULL
+  The resulting Frame has the same referenceFrame() as the Frame and a \c nullptr
   constraint().
 
   \note The scaling factor of the 4x4 matrix is 1.0. */
@@ -198,7 +190,7 @@ Frame Frame::inverse() const {
   referenceFrame() hierarchy is taken into account to define the Frame
   transformation from the world coordinate system. Use matrix() to get the local
   Frame transformation matrix (i.e. defined with respect to the
-  referenceFrame()). These two match when the referenceFrame() is \c NULL.
+  referenceFrame()). These two match when the referenceFrame() is \c nullptr.
 
   The OpenGL format of the result is the transpose of the actual mathematical
   European representation (translation is on the last \e line instead of the
@@ -574,7 +566,7 @@ CGAL_INLINE_FUNCTION
 Quaternion Frame::orientation() const {
   Quaternion res = rotation();
   const Frame *fr = referenceFrame();
-  while (fr != NULL) {
+  while (fr != nullptr) {
     res = fr->rotation() * res;
     fr = fr->referenceFrame();
   }
@@ -691,7 +683,7 @@ Emits the modified() signal if \p refFrame differs from the current
 referenceFrame().
 
 Using this method, you can create a hierarchy of Frames. This hierarchy needs to
-be a tree, which root is the world coordinate system (i.e. a \c NULL
+be a tree, which root is the world coordinate system (i.e. a \c nullptr
 referenceFrame()). A warning is printed and no action is performed if setting \p
 refFrame as the referenceFrame() would create a loop in the Frame hierarchy (see
 settingAsReferenceFrameWillCreateALoop()). */
@@ -712,7 +704,7 @@ void Frame::setReferenceFrame(const Frame *const refFrame) {
 CGAL_INLINE_FUNCTION
 bool Frame::settingAsReferenceFrameWillCreateALoop(const Frame *const frame) {
   const Frame *f = frame;
-  while (f != NULL) {
+  while (f != nullptr) {
     if (f == this)
       return true;
     f = f->referenceFrame();
@@ -748,7 +740,7 @@ CGAL_INLINE_FUNCTION
 Vec Frame::inverseCoordinatesOf(const Vec &src) const {
   const Frame *fr = this;
   Vec res = src;
-  while (fr != NULL) {
+  while (fr != nullptr) {
     res = fr->localInverseCoordinatesOf(res);
     fr = fr->referenceFrame();
   }
@@ -797,7 +789,7 @@ CGAL_INLINE_FUNCTION
 Vec Frame::coordinatesOfIn(const Vec &src, const Frame *const in) const {
   const Frame *fr = this;
   Vec res = src;
-  while ((fr != NULL) && (fr != in)) {
+  while ((fr != nullptr) && (fr != in)) {
     res = fr->localInverseCoordinatesOf(res);
     fr = fr->referenceFrame();
   }
@@ -892,7 +884,7 @@ CGAL_INLINE_FUNCTION
 Vec Frame::inverseTransformOf(const Vec &src) const {
   const Frame *fr = this;
   Vec res = src;
-  while (fr != NULL) {
+  while (fr != nullptr) {
     res = fr->localInverseTransformOf(res);
     fr = fr->referenceFrame();
   }
@@ -942,7 +934,7 @@ CGAL_INLINE_FUNCTION
 Vec Frame::transformOfIn(const Vec &src, const Frame *const in) const {
   const Frame *fr = this;
   Vec res = src;
-  while ((fr != NULL) && (fr != in)) {
+  while ((fr != nullptr) && (fr != in)) {
     res = fr->localInverseTransformOf(res);
     fr = fr->referenceFrame();
   }
@@ -1092,7 +1084,7 @@ alignment. The new Frame's position() is such that the \p frame position
 (computed with coordinatesOf(), in the Frame coordinates system) does not
 change.
 
-\p frame may be \c NULL and then represents the world coordinate system (same
+\p frame may be \c nullptr and then represents the world coordinate system (same
 convention than for the referenceFrame()).
 
 The rotation (and translation when \p move is \c true) applied to the Frame are
