@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Triangulation/include/CGAL/Regular_triangulation.h $
-// $Id: Regular_triangulation.h 257b180 %aI Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Triangulation/include/CGAL/Regular_triangulation.h $
+// $Id: Regular_triangulation.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Clement Jamin
 
@@ -555,7 +546,7 @@ Regular_triangulation<Traits, TDS>
     maximal_dimension(),
     flat_orientation_ ?
     std::pair<int, const Flat_orientation_d *>(current_dimension(), flat_orientation_.get_ptr())
-    : std::pair<int, const Flat_orientation_d *>((std::numeric_limits<int>::max)(), NULL) );
+    : std::pair<int, const Flat_orientation_d *>((std::numeric_limits<int>::max)(), nullptr) );
 
   Dark_s_handle dark_s;
   Dark_v_handle dark_v;
@@ -751,16 +742,16 @@ Regular_triangulation<Traits, TDS>
       Rotor light_r(light_s, li, light_i);
       typename Dark_triangulation::Rotor dark_r(dark_s, di, dark_i);
 
-      while( simps.contains(cpp11::get<0>(light_r)->neighbor(cpp11::get<1>(light_r))) )
+      while( simps.contains(std::get<0>(light_r)->neighbor(std::get<1>(light_r))) )
         light_r = rotate_rotor(light_r);
 
-      while( conflict_zone.contains(cpp11::get<0>(dark_r)->neighbor(cpp11::get<1>(dark_r))) )
+      while( conflict_zone.contains(std::get<0>(dark_r)->neighbor(std::get<1>(dark_r))) )
         dark_r = dark_side.rotate_rotor(dark_r);
 
-      Dark_s_handle dark_ns = cpp11::get<0>(dark_r);
-      int dark_ni = cpp11::get<1>(dark_r);
-      Full_cell_handle light_ns = cpp11::get<0>(light_r);
-      int light_ni = cpp11::get<1>(light_r);
+      Dark_s_handle dark_ns = std::get<0>(dark_r);
+      int dark_ni = std::get<1>(dark_r);
+      Full_cell_handle light_ns = std::get<0>(light_r);
+      int light_ni = std::get<1>(light_r);
       // mark dark_r as visited:
       // TODO try by marking with Dark_v_handle (vertex)
       Dark_s_handle outside = dark_ns->neighbor(dark_ni);
