@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Segment_Delaunay_graph_Linf_2/include/CGAL/Segment_Delaunay_graph_Linf_2/Segment_Delaunay_graph_Linf_hierarchy_2_impl.h $
-// $Id: Segment_Delaunay_graph_Linf_hierarchy_2_impl.h 4e15225 %aI Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Segment_Delaunay_graph_Linf_2/include/CGAL/Segment_Delaunay_graph_Linf_2/Segment_Delaunay_graph_Linf_hierarchy_2_impl.h $
+// $Id: Segment_Delaunay_graph_Linf_hierarchy_2_impl.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 // 
 //
 // Author(s)     : Panagiotis Cheilaris, Sandeep Kumar Dey, Evanthia Papadopoulou
@@ -183,7 +174,7 @@ insert_point(const Point_2& p, const Storage_site_2& ss, int level,
 
   CGAL_assertion( vertex != Vertex_handle() );
 
-  if ( vertices != NULL ) { vertices[0] = vertex; }
+  if ( vertices != nullptr ) { vertices[0] = vertex; }
 
   // insert at other levels
   Vertex_handle previous = vertex;
@@ -240,7 +231,7 @@ insert_point(const Point_2& p, const Storage_site_2& ss, int level,
 
     CGAL_assertion( vertex != Vertex_handle() );
 
-    if ( vertices != NULL ) { vertices[k] = vertex; }
+    if ( vertices != nullptr ) { vertices[k] = vertex; }
 
     vertex->set_down(previous); // link with other levels
     previous->set_up(vertex);
@@ -301,7 +292,7 @@ insert_point(const Site_2& t, const Storage_site_2& ss,
 
     CGAL_assertion( vertex != Vertex_handle() );
 
-    if ( vertices != NULL ) { vertices[k] = vertex; }
+    if ( vertices != nullptr ) { vertices[k] = vertex; }
 
     vertex->set_down(previous); // link with other levels
     previous->set_up(vertex);
@@ -564,7 +555,7 @@ insert_segment_in_upper_levels(const Site_2& t, const Storage_site_2& ss,
 			       const Vertex_handle* vertices,
 			       int level, Tag_true /* stag */)
 {
-  CGAL_precondition( vertices != NULL );
+  CGAL_precondition( vertices != nullptr );
   CGAL_precondition( vbelow != Vertex_handle() );
 
   // insert at all upper levels
