@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Surface_mesh_parameterization/include/CGAL/Surface_mesh_parameterization/MVC_post_processor_3.h $
-// $Id: MVC_post_processor_3.h 6b43eaa %aI Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/Surface_mesh_parameterization/include/CGAL/Surface_mesh_parameterization/MVC_post_processor_3.h $
+// $Id: MVC_post_processor_3.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mael Rouxel-Labbé
 
@@ -41,7 +32,6 @@
 
 #include <CGAL/Default.h>
 
-#include <boost/foreach.hpp>
 #include <boost/unordered_set.hpp>
 
 #include <vector>
@@ -190,7 +180,7 @@ private:
                        VertexUVMap uvmap,
                        const VertexIndexMap vimap) const
   {
-    BOOST_FOREACH(vertex_descriptor vd, vertices) {
+    for(vertex_descriptor vd : vertices) {
       int index = get(vimap, vd);
       NT u = Xu(index);
       NT v = Xv(index);
@@ -221,8 +211,8 @@ private:
   {
     // @fixme unefficient: use sweep line algorithms instead of brute force
 
-    BOOST_FOREACH(halfedge_descriptor hd_1, halfedges_around_face(bhd, mesh)) {
-      BOOST_FOREACH(halfedge_descriptor hd_2, halfedges_around_face(bhd, mesh)) {
+    for(halfedge_descriptor hd_1 : halfedges_around_face(bhd, mesh)) {
+      for(halfedge_descriptor hd_2 : halfedges_around_face(bhd, mesh)) {
         if(hd_1 == hd_2 || // equality
            next(hd_1, mesh) == hd_2 || next(hd_2, mesh) == hd_1) // adjacency
           continue;
@@ -292,9 +282,9 @@ private:
   {
     // Build the constrained triangulation
 
-    // Since the border is closed and we are interest in triangles that are outside
+    // Since the border is closed and we are interested in triangles that are outside
     // of the border, we actually only need to insert points on the border
-    BOOST_FOREACH(halfedge_descriptor hd, halfedges_around_face(bhd, mesh)) {
+    for(halfedge_descriptor hd : halfedges_around_face(bhd, mesh)) {
       vertex_descriptor s = source(hd, mesh);
       const Point_2& sp = get(uvmap, s);
 
@@ -303,7 +293,7 @@ private:
     }
 
     // Insert constraints (the border)
-    BOOST_FOREACH(halfedge_descriptor hd, halfedges_around_face(bhd, mesh)) {
+    for(halfedge_descriptor hd : halfedges_around_face(bhd, mesh)) {
       vertex_descriptor s = source(hd, mesh), t = target(hd, mesh);
       const Point_2& sp = get(uvmap, s), tp = get(uvmap, t);
 
@@ -603,7 +593,7 @@ private:
     }
 
     // Loop over the faces of 'mesh'
-    BOOST_FOREACH(face_descriptor fd, faces) {
+    for(face_descriptor fd : faces) {
       fill_linear_system_matrix_mvc_from_mesh_face(mesh, fd, uvmap, vimap, vpmap, A);
     }
 
@@ -620,7 +610,7 @@ private:
                        const VertexParameterizedMap vpmap,
                        Vector& Bu, Vector& Bv) const
   {
-    BOOST_FOREACH(vertex_descriptor vd, vertices) {
+    for(vertex_descriptor vd : vertices) {
       int index = get(vimap, vd);
       const Point_2& uv = get(uvmap, vd);
       if(!get(vpmap, vd)) { // not yet parameterized
@@ -701,7 +691,7 @@ private:
     CGAL_postcondition_code
     (
       // make sure that the constrained vertices have not been moved
-      BOOST_FOREACH(vertex_descriptor vd, vertices) {
+      for(vertex_descriptor vd : vertices) {
         if(get(vpmap, vd)) {
           int index = get(vimap, vd);
           CGAL_postcondition(std::abs(Xu[index] - Bu[index] ) < 1e-10);
